# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #

from .account_ttl import AccountTtl
from .address import Address
from .animated_chat_photo import AnimatedChatPhoto
from .animation import Animation
from .animations import Animations
from .audio import Audio
from .authentication_code_info import AuthenticationCodeInfo
from .authentication_code_type import (
    AuthenticationCodeType,
    AuthenticationCodeTypeCall,
    AuthenticationCodeTypeFlashCall,
    AuthenticationCodeTypeSms,
    AuthenticationCodeTypeTelegramMessage,
)
from .authorization_state import (
    AuthorizationState,
    AuthorizationStateClosed,
    AuthorizationStateClosing,
    AuthorizationStateLoggingOut,
    AuthorizationStateReady,
    AuthorizationStateWaitCode,
    AuthorizationStateWaitEncryptionKey,
    AuthorizationStateWaitOtherDeviceConfirmation,
    AuthorizationStateWaitPassword,
    AuthorizationStateWaitPhoneNumber,
    AuthorizationStateWaitRegistration,
    AuthorizationStateWaitTdlibParameters,
)
from .auto_download_settings import AutoDownloadSettings
from .auto_download_settings_presets import AutoDownloadSettingsPresets
from .background import Background
from .background_fill import (
    BackgroundFill,
    BackgroundFillFreeformGradient,
    BackgroundFillGradient,
    BackgroundFillSolid,
)
from .background_type import (
    BackgroundType,
    BackgroundTypeFill,
    BackgroundTypePattern,
    BackgroundTypeWallpaper,
)
from .backgrounds import Backgrounds
from .bank_card_action_open_url import BankCardActionOpenUrl
from .bank_card_info import BankCardInfo
from .basic_group import BasicGroup
from .basic_group_full_info import BasicGroupFullInfo
from .bot_command import BotCommand
from .bot_command_scope import (
    BotCommandScope,
    BotCommandScopeAllChatAdministrators,
    BotCommandScopeAllGroupChats,
    BotCommandScopeAllPrivateChats,
    BotCommandScopeChat,
    BotCommandScopeChatAdministrators,
    BotCommandScopeChatMember,
    BotCommandScopeDefault,
)
from .bot_commands import BotCommands
from .call import Call
from .call_discard_reason import (
    CallDiscardReason,
    CallDiscardReasonDeclined,
    CallDiscardReasonDisconnected,
    CallDiscardReasonEmpty,
    CallDiscardReasonHungUp,
    CallDiscardReasonMissed,
)
from .call_id import CallId
from .call_problem import (
    CallProblem,
    CallProblemDistortedSpeech,
    CallProblemDistortedVideo,
    CallProblemDropped,
    CallProblemEcho,
    CallProblemInterruptions,
    CallProblemNoise,
    CallProblemPixelatedVideo,
    CallProblemSilentLocal,
    CallProblemSilentRemote,
)
from .call_protocol import CallProtocol
from .call_server import CallServer
from .call_server_type import (
    CallServerType,
    CallServerTypeTelegramReflector,
    CallServerTypeWebrtc,
)
from .call_state import (
    CallState,
    CallStateDiscarded,
    CallStateError,
    CallStateExchangingKeys,
    CallStateHangingUp,
    CallStatePending,
    CallStateReady,
)
from .callback_query_answer import CallbackQueryAnswer
from .callback_query_payload import (
    CallbackQueryPayload,
    CallbackQueryPayloadData,
    CallbackQueryPayloadDataWithPassword,
    CallbackQueryPayloadGame,
)
from .can_transfer_ownership_result import (
    CanTransferOwnershipResult,
    CanTransferOwnershipResultOk,
    CanTransferOwnershipResultPasswordNeeded,
    CanTransferOwnershipResultPasswordTooFresh,
    CanTransferOwnershipResultSessionTooFresh,
)
from .chat import Chat
from .chat_action import (
    ChatAction,
    ChatActionCancel,
    ChatActionChoosingContact,
    ChatActionChoosingLocation,
    ChatActionRecordingVideo,
    ChatActionRecordingVideoNote,
    ChatActionRecordingVoiceNote,
    ChatActionStartPlayingGame,
    ChatActionTyping,
    ChatActionUploadingDocument,
    ChatActionUploadingPhoto,
    ChatActionUploadingVideo,
    ChatActionUploadingVideoNote,
    ChatActionUploadingVoiceNote,
)
from .chat_action_bar import (
    ChatActionBar,
    ChatActionBarAddContact,
    ChatActionBarInviteMembers,
    ChatActionBarReportAddBlock,
    ChatActionBarReportSpam,
    ChatActionBarReportUnrelatedLocation,
    ChatActionBarSharePhoneNumber,
)
from .chat_administrator import ChatAdministrator
from .chat_administrators import ChatAdministrators
from .chat_event import ChatEvent
from .chat_event_action import (
    ChatEventAction,
    ChatEventDescriptionChanged,
    ChatEventInviteLinkDeleted,
    ChatEventInviteLinkEdited,
    ChatEventInviteLinkRevoked,
    ChatEventInvitesToggled,
    ChatEventIsAllHistoryAvailableToggled,
    ChatEventLinkedChatChanged,
    ChatEventLocationChanged,
    ChatEventMemberInvited,
    ChatEventMemberJoined,
    ChatEventMemberJoinedByInviteLink,
    ChatEventMemberLeft,
    ChatEventMemberPromoted,
    ChatEventMemberRestricted,
    ChatEventMessageDeleted,
    ChatEventMessageEdited,
    ChatEventMessagePinned,
    ChatEventMessageTtlSettingChanged,
    ChatEventMessageUnpinned,
    ChatEventPermissionsChanged,
    ChatEventPhotoChanged,
    ChatEventPollStopped,
    ChatEventSignMessagesToggled,
    ChatEventSlowModeDelayChanged,
    ChatEventStickerSetChanged,
    ChatEventTitleChanged,
    ChatEventUsernameChanged,
    ChatEventVoiceChatCreated,
    ChatEventVoiceChatDiscarded,
    ChatEventVoiceChatMuteNewParticipantsToggled,
    ChatEventVoiceChatParticipantIsMutedToggled,
    ChatEventVoiceChatParticipantVolumeLevelChanged,
)
from .chat_event_log_filters import ChatEventLogFilters
from .chat_events import ChatEvents
from .chat_filter import ChatFilter
from .chat_filter_info import ChatFilterInfo
from .chat_invite_link import ChatInviteLink
from .chat_invite_link_count import ChatInviteLinkCount
from .chat_invite_link_counts import ChatInviteLinkCounts
from .chat_invite_link_info import ChatInviteLinkInfo
from .chat_invite_link_member import ChatInviteLinkMember
from .chat_invite_link_members import ChatInviteLinkMembers
from .chat_invite_links import ChatInviteLinks
from .chat_list import (
    ChatList,
    ChatListArchive,
    ChatListFilter,
    ChatListMain,
)
from .chat_lists import ChatLists
from .chat_location import ChatLocation
from .chat_member import ChatMember
from .chat_member_status import (
    ChatMemberStatus,
    ChatMemberStatusAdministrator,
    ChatMemberStatusBanned,
    ChatMemberStatusCreator,
    ChatMemberStatusLeft,
    ChatMemberStatusMember,
    ChatMemberStatusRestricted,
)
from .chat_members import ChatMembers
from .chat_members_filter import (
    ChatMembersFilter,
    ChatMembersFilterAdministrators,
    ChatMembersFilterBanned,
    ChatMembersFilterBots,
    ChatMembersFilterContacts,
    ChatMembersFilterMembers,
    ChatMembersFilterMention,
    ChatMembersFilterRestricted,
)
from .chat_nearby import ChatNearby
from .chat_notification_settings import ChatNotificationSettings
from .chat_permissions import ChatPermissions
from .chat_photo import ChatPhoto
from .chat_photo_info import ChatPhotoInfo
from .chat_photos import ChatPhotos
from .chat_position import ChatPosition
from .chat_report_reason import (
    ChatReportReason,
    ChatReportReasonChildAbuse,
    ChatReportReasonCopyright,
    ChatReportReasonCustom,
    ChatReportReasonFake,
    ChatReportReasonPornography,
    ChatReportReasonSpam,
    ChatReportReasonUnrelatedLocation,
    ChatReportReasonViolence,
)
from .chat_source import (
    ChatSource,
    ChatSourceMtprotoProxy,
    ChatSourcePublicServiceAnnouncement,
)
from .chat_statistics import (
    ChatStatistics,
    ChatStatisticsChannel,
    ChatStatisticsSupergroup,
)
from .chat_statistics_administrator_actions_info import ChatStatisticsAdministratorActionsInfo
from .chat_statistics_inviter_info import ChatStatisticsInviterInfo
from .chat_statistics_message_interaction_info import ChatStatisticsMessageInteractionInfo
from .chat_statistics_message_sender_info import ChatStatisticsMessageSenderInfo
from .chat_type import (
    ChatType,
    ChatTypeBasicGroup,
    ChatTypePrivate,
    ChatTypeSecret,
    ChatTypeSupergroup,
)
from .chats import Chats
from .chats_nearby import ChatsNearby
from .check_chat_username_result import (
    CheckChatUsernameResult,
    CheckChatUsernameResultOk,
    CheckChatUsernameResultPublicChatsTooMuch,
    CheckChatUsernameResultPublicGroupsUnavailable,
    CheckChatUsernameResultUsernameInvalid,
    CheckChatUsernameResultUsernameOccupied,
)
from .check_sticker_set_name_result import (
    CheckStickerSetNameResult,
    CheckStickerSetNameResultNameInvalid,
    CheckStickerSetNameResultNameOccupied,
    CheckStickerSetNameResultOk,
)
from .closed_vector_path import ClosedVectorPath
from .connected_website import ConnectedWebsite
from .connected_websites import ConnectedWebsites
from .connection_state import (
    ConnectionState,
    ConnectionStateConnecting,
    ConnectionStateConnectingToProxy,
    ConnectionStateReady,
    ConnectionStateUpdating,
    ConnectionStateWaitingForNetwork,
)
from .contact import Contact
from .count import Count
from .countries import Countries
from .country_info import CountryInfo
from .custom_request_result import CustomRequestResult
from .database_statistics import DatabaseStatistics
from .date import Date
from .date_range import DateRange
from .dated_file import DatedFile
from .deep_link_info import DeepLinkInfo
from .device_token import (
    DeviceToken,
    DeviceTokenApplePush,
    DeviceTokenApplePushVoIP,
    DeviceTokenBlackBerryPush,
    DeviceTokenFirebaseCloudMessaging,
    DeviceTokenMicrosoftPush,
    DeviceTokenMicrosoftPushVoIP,
    DeviceTokenSimplePush,
    DeviceTokenTizenPush,
    DeviceTokenUbuntuPush,
    DeviceTokenWebPush,
    DeviceTokenWindowsPush,
)
from .dice_stickers import (
    DiceStickers,
    DiceStickersRegular,
    DiceStickersSlotMachine,
)
from .document import Document
from .draft_message import DraftMessage
from .email_address_authentication_code_info import EmailAddressAuthenticationCodeInfo
from .emojis import Emojis
from .encrypted_credentials import EncryptedCredentials
from .encrypted_passport_element import EncryptedPassportElement
from .error import Error
from .file import File
from .file_part import FilePart
from .file_type import (
    FileType,
    FileTypeAnimation,
    FileTypeAudio,
    FileTypeDocument,
    FileTypeNone,
    FileTypePhoto,
    FileTypeProfilePhoto,
    FileTypeSecret,
    FileTypeSecretThumbnail,
    FileTypeSecure,
    FileTypeSticker,
    FileTypeThumbnail,
    FileTypeUnknown,
    FileTypeVideo,
    FileTypeVideoNote,
    FileTypeVoiceNote,
    FileTypeWallpaper,
)
from .formatted_text import FormattedText
from .found_messages import FoundMessages
from .game import Game
from .game_high_score import GameHighScore
from .game_high_scores import GameHighScores
from .group_call import GroupCall
from .group_call_id import GroupCallId
from .group_call_participant import GroupCallParticipant
from .group_call_participant_video_info import GroupCallParticipantVideoInfo
from .group_call_recent_speaker import GroupCallRecentSpeaker
from .group_call_video_source_group import GroupCallVideoSourceGroup
from .hashtags import Hashtags
from .http_url import HttpUrl
from .identity_document import IdentityDocument
from .imported_contacts import ImportedContacts
from .inline_keyboard_button import InlineKeyboardButton
from .inline_keyboard_button_type import (
    InlineKeyboardButtonType,
    InlineKeyboardButtonTypeBuy,
    InlineKeyboardButtonTypeCallback,
    InlineKeyboardButtonTypeCallbackGame,
    InlineKeyboardButtonTypeCallbackWithPassword,
    InlineKeyboardButtonTypeLoginUrl,
    InlineKeyboardButtonTypeSwitchInline,
    InlineKeyboardButtonTypeUrl,
)
from .inline_query_result import (
    InlineQueryResult,
    InlineQueryResultAnimation,
    InlineQueryResultArticle,
    InlineQueryResultAudio,
    InlineQueryResultContact,
    InlineQueryResultDocument,
    InlineQueryResultGame,
    InlineQueryResultLocation,
    InlineQueryResultPhoto,
    InlineQueryResultSticker,
    InlineQueryResultVenue,
    InlineQueryResultVideo,
    InlineQueryResultVoiceNote,
)
from .inline_query_results import InlineQueryResults
from .input_background import (
    InputBackground,
    InputBackgroundLocal,
    InputBackgroundRemote,
)
from .input_chat_photo import (
    InputChatPhoto,
    InputChatPhotoAnimation,
    InputChatPhotoPrevious,
    InputChatPhotoStatic,
)
from .input_credentials import (
    InputCredentials,
    InputCredentialsApplePay,
    InputCredentialsGooglePay,
    InputCredentialsNew,
    InputCredentialsSaved,
)
from .input_file import (
    InputFile,
    InputFileGenerated,
    InputFileId,
    InputFileLocal,
    InputFileRemote,
)
from .input_identity_document import InputIdentityDocument
from .input_inline_query_result import (
    InputInlineQueryResult,
    InputInlineQueryResultAnimation,
    InputInlineQueryResultArticle,
    InputInlineQueryResultAudio,
    InputInlineQueryResultContact,
    InputInlineQueryResultDocument,
    InputInlineQueryResultGame,
    InputInlineQueryResultLocation,
    InputInlineQueryResultPhoto,
    InputInlineQueryResultSticker,
    InputInlineQueryResultVenue,
    InputInlineQueryResultVideo,
    InputInlineQueryResultVoiceNote,
)
from .input_message_content import (
    InputMessageAnimation,
    InputMessageAudio,
    InputMessageContact,
    InputMessageContent,
    InputMessageDice,
    InputMessageDocument,
    InputMessageForwarded,
    InputMessageGame,
    InputMessageInvoice,
    InputMessageLocation,
    InputMessagePhoto,
    InputMessagePoll,
    InputMessageSticker,
    InputMessageText,
    InputMessageVenue,
    InputMessageVideo,
    InputMessageVideoNote,
    InputMessageVoiceNote,
)
from .input_passport_element import (
    InputPassportElement,
    InputPassportElementAddress,
    InputPassportElementBankStatement,
    InputPassportElementDriverLicense,
    InputPassportElementEmailAddress,
    InputPassportElementIdentityCard,
    InputPassportElementInternalPassport,
    InputPassportElementPassport,
    InputPassportElementPassportRegistration,
    InputPassportElementPersonalDetails,
    InputPassportElementPhoneNumber,
    InputPassportElementRentalAgreement,
    InputPassportElementTemporaryRegistration,
    InputPassportElementUtilityBill,
)
from .input_passport_element_error import InputPassportElementError
from .input_passport_element_error_source import (
    InputPassportElementErrorSource,
    InputPassportElementErrorSourceDataField,
    InputPassportElementErrorSourceFile,
    InputPassportElementErrorSourceFiles,
    InputPassportElementErrorSourceFrontSide,
    InputPassportElementErrorSourceReverseSide,
    InputPassportElementErrorSourceSelfie,
    InputPassportElementErrorSourceTranslationFile,
    InputPassportElementErrorSourceTranslationFiles,
    InputPassportElementErrorSourceUnspecified,
)
from .input_personal_document import InputPersonalDocument
from .input_sticker import (
    InputSticker,
    InputStickerAnimated,
    InputStickerStatic,
)
from .input_thumbnail import InputThumbnail
from .internal_link_type import (
    InternalLinkType,
    InternalLinkTypeActiveSessions,
    InternalLinkTypeAuthenticationCode,
    InternalLinkTypeBackground,
    InternalLinkTypeBotStart,
    InternalLinkTypeBotStartInGroup,
    InternalLinkTypeChangePhoneNumber,
    InternalLinkTypeChatInvite,
    InternalLinkTypeFilterSettings,
    InternalLinkTypeGame,
    InternalLinkTypeLanguagePack,
    InternalLinkTypeMessage,
    InternalLinkTypeMessageDraft,
    InternalLinkTypePassportDataRequest,
    InternalLinkTypePhoneNumberConfirmation,
    InternalLinkTypeProxy,
    InternalLinkTypePublicChat,
    InternalLinkTypeQrCodeAuthentication,
    InternalLinkTypeSettings,
    InternalLinkTypeStickerSet,
    InternalLinkTypeTheme,
    InternalLinkTypeThemeSettings,
    InternalLinkTypeUnknownDeepLink,
    InternalLinkTypeVoiceChat,
)
from .invoice import Invoice
from .json_value import (
    JsonObjectMember,
    JsonValue,
    JsonValueArray,
    JsonValueBoolean,
    JsonValueNull,
    JsonValueNumber,
    JsonValueObject,
    JsonValueString,
)
from .keyboard_button import KeyboardButton
from .keyboard_button_type import (
    KeyboardButtonType,
    KeyboardButtonTypeRequestLocation,
    KeyboardButtonTypeRequestPhoneNumber,
    KeyboardButtonTypeRequestPoll,
    KeyboardButtonTypeText,
)
from .labeled_price_part import LabeledPricePart
from .language_pack_info import LanguagePackInfo
from .language_pack_string import LanguagePackString
from .language_pack_string_value import (
    LanguagePackStringValue,
    LanguagePackStringValueDeleted,
    LanguagePackStringValueOrdinary,
    LanguagePackStringValuePluralized,
)
from .language_pack_strings import LanguagePackStrings
from .local_file import LocalFile
from .localization_target_info import LocalizationTargetInfo
from .location import Location
from .log_stream import (
    LogStream,
    LogStreamDefault,
    LogStreamEmpty,
    LogStreamFile,
)
from .log_tags import LogTags
from .log_verbosity_level import LogVerbosityLevel
from .login_url_info import (
    LoginUrlInfo,
    LoginUrlInfoOpen,
    LoginUrlInfoRequestConfirmation,
)
from .mask_point import (
    MaskPoint,
    MaskPointChin,
    MaskPointEyes,
    MaskPointForehead,
    MaskPointMouth,
)
from .mask_position import MaskPosition
from .message import Message
from .message_content import (
    MessageAnimation,
    MessageAudio,
    MessageBasicGroupChatCreate,
    MessageCall,
    MessageChatAddMembers,
    MessageChatChangePhoto,
    MessageChatChangeTitle,
    MessageChatDeleteMember,
    MessageChatDeletePhoto,
    MessageChatJoinByLink,
    MessageChatSetTtl,
    MessageChatUpgradeFrom,
    MessageChatUpgradeTo,
    MessageContact,
    MessageContactRegistered,
    MessageContent,
    MessageCustomServiceAction,
    MessageDice,
    MessageDocument,
    MessageExpiredPhoto,
    MessageExpiredVideo,
    MessageGame,
    MessageGameScore,
    MessageInviteVoiceChatParticipants,
    MessageInvoice,
    MessageLocation,
    MessagePassportDataReceived,
    MessagePassportDataSent,
    MessagePaymentSuccessful,
    MessagePaymentSuccessfulBot,
    MessagePhoto,
    MessagePinMessage,
    MessagePoll,
    MessageProximityAlertTriggered,
    MessageScreenshotTaken,
    MessageSticker,
    MessageSupergroupChatCreate,
    MessageText,
    MessageUnsupported,
    MessageVenue,
    MessageVideo,
    MessageVideoNote,
    MessageVoiceChatEnded,
    MessageVoiceChatScheduled,
    MessageVoiceChatStarted,
    MessageVoiceNote,
    MessageWebsiteConnected,
)
from .message_copy_options import MessageCopyOptions
from .message_file_type import (
    MessageFileType,
    MessageFileTypeGroup,
    MessageFileTypePrivate,
    MessageFileTypeUnknown,
)
from .message_forward_info import MessageForwardInfo
from .message_forward_origin import (
    MessageForwardOrigin,
    MessageForwardOriginChannel,
    MessageForwardOriginChat,
    MessageForwardOriginHiddenUser,
    MessageForwardOriginMessageImport,
    MessageForwardOriginUser,
)
from .message_interaction_info import MessageInteractionInfo
from .message_link import MessageLink
from .message_link_info import MessageLinkInfo
from .message_reply_info import MessageReplyInfo
from .message_scheduling_state import (
    MessageSchedulingState,
    MessageSchedulingStateSendAtDate,
    MessageSchedulingStateSendWhenOnline,
)
from .message_send_options import MessageSendOptions
from .message_sender import (
    MessageSender,
    MessageSenderChat,
    MessageSenderUser,
)
from .message_senders import MessageSenders
from .message_sending_state import (
    MessageSendingState,
    MessageSendingStateFailed,
    MessageSendingStatePending,
)
from .message_statistics import MessageStatistics
from .message_thread_info import MessageThreadInfo
from .messages import Messages
from .minithumbnail import Minithumbnail
from .network_statistics import NetworkStatistics
from .network_statistics_entry import (
    NetworkStatisticsEntry,
    NetworkStatisticsEntryCall,
    NetworkStatisticsEntryFile,
)
from .network_type import (
    NetworkType,
    NetworkTypeMobile,
    NetworkTypeMobileRoaming,
    NetworkTypeNone,
    NetworkTypeOther,
    NetworkTypeWiFi,
)
from .notification import Notification
from .notification_group import NotificationGroup
from .notification_group_type import (
    NotificationGroupType,
    NotificationGroupTypeCalls,
    NotificationGroupTypeMentions,
    NotificationGroupTypeMessages,
    NotificationGroupTypeSecretChat,
)
from .notification_settings_scope import (
    NotificationSettingsScope,
    NotificationSettingsScopeChannelChats,
    NotificationSettingsScopeGroupChats,
    NotificationSettingsScopePrivateChats,
)
from .notification_type import (
    NotificationType,
    NotificationTypeNewCall,
    NotificationTypeNewMessage,
    NotificationTypeNewPushMessage,
    NotificationTypeNewSecretChat,
)
from .ok import Ok
from .option_value import (
    OptionValue,
    OptionValueBoolean,
    OptionValueEmpty,
    OptionValueInteger,
    OptionValueString,
)
from .order_info import OrderInfo
from .page_block import (
    PageBlock,
    PageBlockAnchor,
    PageBlockAnimation,
    PageBlockAudio,
    PageBlockAuthorDate,
    PageBlockBlockQuote,
    PageBlockChatLink,
    PageBlockCollage,
    PageBlockCover,
    PageBlockDetails,
    PageBlockDivider,
    PageBlockEmbedded,
    PageBlockEmbeddedPost,
    PageBlockFooter,
    PageBlockHeader,
    PageBlockKicker,
    PageBlockList,
    PageBlockListItem,
    PageBlockMap,
    PageBlockParagraph,
    PageBlockPhoto,
    PageBlockPreformatted,
    PageBlockPullQuote,
    PageBlockRelatedArticles,
    PageBlockSlideshow,
    PageBlockSubheader,
    PageBlockSubtitle,
    PageBlockTable,
    PageBlockTitle,
    PageBlockVideo,
    PageBlockVoiceNote,
)
from .page_block_caption import PageBlockCaption
from .page_block_horizontal_alignment import (
    PageBlockHorizontalAlignment,
    PageBlockHorizontalAlignmentCenter,
    PageBlockHorizontalAlignmentLeft,
    PageBlockHorizontalAlignmentRight,
)
from .page_block_related_article import PageBlockRelatedArticle
from .page_block_table_cell import PageBlockTableCell
from .page_block_vertical_alignment import (
    PageBlockVerticalAlignment,
    PageBlockVerticalAlignmentBottom,
    PageBlockVerticalAlignmentMiddle,
    PageBlockVerticalAlignmentTop,
)
from .passport_authorization_form import PassportAuthorizationForm
from .passport_element import (
    PassportElement,
    PassportElementAddress,
    PassportElementBankStatement,
    PassportElementDriverLicense,
    PassportElementEmailAddress,
    PassportElementIdentityCard,
    PassportElementInternalPassport,
    PassportElementPassport,
    PassportElementPassportRegistration,
    PassportElementPersonalDetails,
    PassportElementPhoneNumber,
    PassportElementRentalAgreement,
    PassportElementTemporaryRegistration,
    PassportElementUtilityBill,
)
from .passport_element_error import PassportElementError
from .passport_element_error_source import (
    PassportElementErrorSource,
    PassportElementErrorSourceDataField,
    PassportElementErrorSourceFile,
    PassportElementErrorSourceFiles,
    PassportElementErrorSourceFrontSide,
    PassportElementErrorSourceReverseSide,
    PassportElementErrorSourceSelfie,
    PassportElementErrorSourceTranslationFile,
    PassportElementErrorSourceTranslationFiles,
    PassportElementErrorSourceUnspecified,
)
from .passport_element_type import (
    PassportElementType,
    PassportElementTypeAddress,
    PassportElementTypeBankStatement,
    PassportElementTypeDriverLicense,
    PassportElementTypeEmailAddress,
    PassportElementTypeIdentityCard,
    PassportElementTypeInternalPassport,
    PassportElementTypePassport,
    PassportElementTypePassportRegistration,
    PassportElementTypePersonalDetails,
    PassportElementTypePhoneNumber,
    PassportElementTypeRentalAgreement,
    PassportElementTypeTemporaryRegistration,
    PassportElementTypeUtilityBill,
)
from .passport_elements import PassportElements
from .passport_elements_with_errors import PassportElementsWithErrors
from .passport_required_element import PassportRequiredElement
from .passport_suitable_element import PassportSuitableElement
from .password_state import PasswordState
from .payment_form import PaymentForm
from .payment_form_theme import PaymentFormTheme
from .payment_receipt import PaymentReceipt
from .payment_result import PaymentResult
from .payments_provider_stripe import PaymentsProviderStripe
from .personal_details import PersonalDetails
from .personal_document import PersonalDocument
from .phone_number_authentication_settings import PhoneNumberAuthenticationSettings
from .phone_number_info import PhoneNumberInfo
from .photo import Photo
from .photo_size import PhotoSize
from .point import Point
from .poll import Poll
from .poll_option import PollOption
from .poll_type import (
    PollType,
    PollTypeQuiz,
    PollTypeRegular,
)
from .profile_photo import ProfilePhoto
from .proxies import Proxies
from .proxy import Proxy
from .proxy_type import (
    ProxyType,
    ProxyTypeHttp,
    ProxyTypeMtproto,
    ProxyTypeSocks5,
)
from .public_chat_type import (
    PublicChatType,
    PublicChatTypeHasUsername,
    PublicChatTypeIsLocationBased,
)
from .push_message_content import (
    PushMessageContent,
    PushMessageContentAnimation,
    PushMessageContentAudio,
    PushMessageContentBasicGroupChatCreate,
    PushMessageContentChatAddMembers,
    PushMessageContentChatChangePhoto,
    PushMessageContentChatChangeTitle,
    PushMessageContentChatDeleteMember,
    PushMessageContentChatJoinByLink,
    PushMessageContentContact,
    PushMessageContentContactRegistered,
    PushMessageContentDocument,
    PushMessageContentGame,
    PushMessageContentGameScore,
    PushMessageContentHidden,
    PushMessageContentInvoice,
    PushMessageContentLocation,
    PushMessageContentMediaAlbum,
    PushMessageContentMessageForwards,
    PushMessageContentPhoto,
    PushMessageContentPoll,
    PushMessageContentScreenshotTaken,
    PushMessageContentSticker,
    PushMessageContentText,
    PushMessageContentVideo,
    PushMessageContentVideoNote,
    PushMessageContentVoiceNote,
)
from .push_receiver_id import PushReceiverId
from .recommended_chat_filter import RecommendedChatFilter
from .recommended_chat_filters import RecommendedChatFilters
from .recovery_email_address import RecoveryEmailAddress
from .remote_file import RemoteFile
from .reply_markup import (
    ReplyMarkup,
    ReplyMarkupForceReply,
    ReplyMarkupInlineKeyboard,
    ReplyMarkupRemoveKeyboard,
    ReplyMarkupShowKeyboard,
)
from .reset_password_result import (
    ResetPasswordResult,
    ResetPasswordResultDeclined,
    ResetPasswordResultOk,
    ResetPasswordResultPending,
)
from .rich_text import (
    RichText,
    RichTextAnchor,
    RichTextAnchorLink,
    RichTextBold,
    RichTextEmailAddress,
    RichTextFixed,
    RichTextIcon,
    RichTextItalic,
    RichTextMarked,
    RichTextPhoneNumber,
    RichTextPlain,
    RichTextReference,
    RichTextStrikethrough,
    RichTextSubscript,
    RichTextSuperscript,
    RichTextUnderline,
    RichTextUrl,
    RichTexts,
)
from .saved_credentials import SavedCredentials
from .scope_notification_settings import ScopeNotificationSettings
from .search_messages_filter import (
    SearchMessagesFilter,
    SearchMessagesFilterAnimation,
    SearchMessagesFilterAudio,
    SearchMessagesFilterCall,
    SearchMessagesFilterChatPhoto,
    SearchMessagesFilterDocument,
    SearchMessagesFilterEmpty,
    SearchMessagesFilterFailedToSend,
    SearchMessagesFilterMention,
    SearchMessagesFilterMissedCall,
    SearchMessagesFilterPhoto,
    SearchMessagesFilterPhotoAndVideo,
    SearchMessagesFilterPinned,
    SearchMessagesFilterUnreadMention,
    SearchMessagesFilterUrl,
    SearchMessagesFilterVideo,
    SearchMessagesFilterVideoNote,
    SearchMessagesFilterVoiceAndVideoNote,
    SearchMessagesFilterVoiceNote,
)
from .seconds import Seconds
from .secret_chat import SecretChat
from .secret_chat_state import (
    SecretChatState,
    SecretChatStateClosed,
    SecretChatStatePending,
    SecretChatStateReady,
)
from .session import Session
from .sessions import Sessions
from .shipping_option import ShippingOption
from .statistical_graph import (
    StatisticalGraph,
    StatisticalGraphAsync,
    StatisticalGraphData,
    StatisticalGraphError,
)
from .statistical_value import StatisticalValue
from .sticker import Sticker
from .sticker_set import StickerSet
from .sticker_set_info import StickerSetInfo
from .sticker_sets import StickerSets
from .stickers import Stickers
from .storage_statistics import StorageStatistics
from .storage_statistics_by_chat import StorageStatisticsByChat
from .storage_statistics_by_file_type import StorageStatisticsByFileType
from .storage_statistics_fast import StorageStatisticsFast
from .suggested_action import (
    SuggestedAction,
    SuggestedActionCheckPassword,
    SuggestedActionCheckPhoneNumber,
    SuggestedActionConvertToBroadcastGroup,
    SuggestedActionEnableArchiveAndMuteNewChats,
    SuggestedActionSeeTicksHint,
)
from .supergroup import Supergroup
from .supergroup_full_info import SupergroupFullInfo
from .supergroup_members_filter import (
    SupergroupMembersFilter,
    SupergroupMembersFilterAdministrators,
    SupergroupMembersFilterBanned,
    SupergroupMembersFilterBots,
    SupergroupMembersFilterContacts,
    SupergroupMembersFilterMention,
    SupergroupMembersFilterRecent,
    SupergroupMembersFilterRestricted,
    SupergroupMembersFilterSearch,
)
from .t_me_url import TMeUrl
from .t_me_url_type import (
    TMeUrlType,
    TMeUrlTypeChatInvite,
    TMeUrlTypeStickerSet,
    TMeUrlTypeSupergroup,
    TMeUrlTypeUser,
)
from .t_me_urls import TMeUrls
from .tdlib_parameters import TdlibParameters
from .temporary_password_state import TemporaryPasswordState
from .terms_of_service import TermsOfService
from .test_bytes import TestBytes
from .test_int import TestInt
from .test_string import TestString
from .test_vector_int import TestVectorInt
from .test_vector_int_object import TestVectorIntObject
from .test_vector_string import TestVectorString
from .test_vector_string_object import TestVectorStringObject
from .text import Text
from .text_entities import TextEntities
from .text_entity import TextEntity
from .text_entity_type import (
    TextEntityType,
    TextEntityTypeBankCardNumber,
    TextEntityTypeBold,
    TextEntityTypeBotCommand,
    TextEntityTypeCashtag,
    TextEntityTypeCode,
    TextEntityTypeEmailAddress,
    TextEntityTypeHashtag,
    TextEntityTypeItalic,
    TextEntityTypeMention,
    TextEntityTypeMentionName,
    TextEntityTypePhoneNumber,
    TextEntityTypePre,
    TextEntityTypePreCode,
    TextEntityTypeStrikethrough,
    TextEntityTypeTextUrl,
    TextEntityTypeUnderline,
    TextEntityTypeUrl,
)
from .text_parse_mode import (
    TextParseMode,
    TextParseModeHTML,
    TextParseModeMarkdown,
)
from .thumbnail import Thumbnail
from .thumbnail_format import (
    ThumbnailFormat,
    ThumbnailFormatGif,
    ThumbnailFormatJpeg,
    ThumbnailFormatMpeg4,
    ThumbnailFormatPng,
    ThumbnailFormatTgs,
    ThumbnailFormatWebp,
)
from .top_chat_category import (
    TopChatCategory,
    TopChatCategoryBots,
    TopChatCategoryCalls,
    TopChatCategoryChannels,
    TopChatCategoryForwardChats,
    TopChatCategoryGroups,
    TopChatCategoryInlineBots,
    TopChatCategoryUsers,
)
from .update import (
    Update,
    UpdateActiveNotifications,
    UpdateAnimationSearchParameters,
    UpdateAuthorizationState,
    UpdateBasicGroup,
    UpdateBasicGroupFullInfo,
    UpdateCall,
    UpdateChatActionBar,
    UpdateChatDefaultDisableNotification,
    UpdateChatDraftMessage,
    UpdateChatFilters,
    UpdateChatHasScheduledMessages,
    UpdateChatIsBlocked,
    UpdateChatIsMarkedAsUnread,
    UpdateChatLastMessage,
    UpdateChatMember,
    UpdateChatMessageTtlSetting,
    UpdateChatNotificationSettings,
    UpdateChatOnlineMemberCount,
    UpdateChatPermissions,
    UpdateChatPhoto,
    UpdateChatPosition,
    UpdateChatReadInbox,
    UpdateChatReadOutbox,
    UpdateChatReplyMarkup,
    UpdateChatTitle,
    UpdateChatUnreadMentionCount,
    UpdateChatVoiceChat,
    UpdateConnectionState,
    UpdateDeleteMessages,
    UpdateDiceEmojis,
    UpdateFavoriteStickers,
    UpdateFile,
    UpdateFileGenerationStart,
    UpdateFileGenerationStop,
    UpdateGroupCall,
    UpdateGroupCallParticipant,
    UpdateHavePendingNotifications,
    UpdateInstalledStickerSets,
    UpdateLanguagePackStrings,
    UpdateMessageContent,
    UpdateMessageContentOpened,
    UpdateMessageEdited,
    UpdateMessageInteractionInfo,
    UpdateMessageIsPinned,
    UpdateMessageLiveLocationViewed,
    UpdateMessageMentionRead,
    UpdateMessageSendAcknowledged,
    UpdateMessageSendFailed,
    UpdateMessageSendSucceeded,
    UpdateNewCallSignalingData,
    UpdateNewCallbackQuery,
    UpdateNewChat,
    UpdateNewChosenInlineResult,
    UpdateNewCustomEvent,
    UpdateNewCustomQuery,
    UpdateNewInlineCallbackQuery,
    UpdateNewInlineQuery,
    UpdateNewMessage,
    UpdateNewPreCheckoutQuery,
    UpdateNewShippingQuery,
    UpdateNotification,
    UpdateNotificationGroup,
    UpdateOption,
    UpdatePoll,
    UpdatePollAnswer,
    UpdateRecentStickers,
    UpdateSavedAnimations,
    UpdateScopeNotificationSettings,
    UpdateSecretChat,
    UpdateSelectedBackground,
    UpdateServiceNotification,
    UpdateStickerSet,
    UpdateSuggestedActions,
    UpdateSupergroup,
    UpdateSupergroupFullInfo,
    UpdateTermsOfService,
    UpdateTrendingStickerSets,
    UpdateUnreadChatCount,
    UpdateUnreadMessageCount,
    UpdateUser,
    UpdateUserChatAction,
    UpdateUserFullInfo,
    UpdateUserPrivacySettingRules,
    UpdateUserStatus,
    UpdateUsersNearby,
)
from .updates import Updates
from .user import User
from .user_full_info import UserFullInfo
from .user_privacy_setting import (
    UserPrivacySetting,
    UserPrivacySettingAllowCalls,
    UserPrivacySettingAllowChatInvites,
    UserPrivacySettingAllowFindingByPhoneNumber,
    UserPrivacySettingAllowPeerToPeerCalls,
    UserPrivacySettingShowLinkInForwardedMessages,
    UserPrivacySettingShowPhoneNumber,
    UserPrivacySettingShowProfilePhoto,
    UserPrivacySettingShowStatus,
)
from .user_privacy_setting_rule import (
    UserPrivacySettingRule,
    UserPrivacySettingRuleAllowAll,
    UserPrivacySettingRuleAllowChatMembers,
    UserPrivacySettingRuleAllowContacts,
    UserPrivacySettingRuleAllowUsers,
    UserPrivacySettingRuleRestrictAll,
    UserPrivacySettingRuleRestrictChatMembers,
    UserPrivacySettingRuleRestrictContacts,
    UserPrivacySettingRuleRestrictUsers,
)
from .user_privacy_setting_rules import UserPrivacySettingRules
from .user_status import (
    UserStatus,
    UserStatusEmpty,
    UserStatusLastMonth,
    UserStatusLastWeek,
    UserStatusOffline,
    UserStatusOnline,
    UserStatusRecently,
)
from .user_type import (
    UserType,
    UserTypeBot,
    UserTypeDeleted,
    UserTypeRegular,
    UserTypeUnknown,
)
from .users import Users
from .validated_order_info import ValidatedOrderInfo
from .vector_path_command import (
    VectorPathCommand,
    VectorPathCommandCubicBezierCurve,
    VectorPathCommandLine,
)
from .venue import Venue
from .video import Video
from .video_note import VideoNote
from .voice_chat import VoiceChat
from .voice_note import VoiceNote
from .web_page import WebPage
from .web_page_instant_view import WebPageInstantView

__all__ = [
    "AccountTtl",
    "Address",
    "AnimatedChatPhoto",
    "Animation",
    "Animations",
    "Audio",
    "AuthenticationCodeInfo",
    "AuthenticationCodeType",
    "AuthenticationCodeTypeCall",
    "AuthenticationCodeTypeFlashCall",
    "AuthenticationCodeTypeSms",
    "AuthenticationCodeTypeTelegramMessage",
    "AuthorizationState",
    "AuthorizationStateClosed",
    "AuthorizationStateClosing",
    "AuthorizationStateLoggingOut",
    "AuthorizationStateReady",
    "AuthorizationStateWaitCode",
    "AuthorizationStateWaitEncryptionKey",
    "AuthorizationStateWaitOtherDeviceConfirmation",
    "AuthorizationStateWaitPassword",
    "AuthorizationStateWaitPhoneNumber",
    "AuthorizationStateWaitRegistration",
    "AuthorizationStateWaitTdlibParameters",
    "AutoDownloadSettings",
    "AutoDownloadSettingsPresets",
    "Background",
    "BackgroundFill",
    "BackgroundFillFreeformGradient",
    "BackgroundFillGradient",
    "BackgroundFillSolid",
    "BackgroundType",
    "BackgroundTypeFill",
    "BackgroundTypePattern",
    "BackgroundTypeWallpaper",
    "Backgrounds",
    "BankCardActionOpenUrl",
    "BankCardInfo",
    "BasicGroup",
    "BasicGroupFullInfo",
    "BotCommand",
    "BotCommandScope",
    "BotCommandScopeAllChatAdministrators",
    "BotCommandScopeAllGroupChats",
    "BotCommandScopeAllPrivateChats",
    "BotCommandScopeChat",
    "BotCommandScopeChatAdministrators",
    "BotCommandScopeChatMember",
    "BotCommandScopeDefault",
    "BotCommands",
    "Call",
    "CallDiscardReason",
    "CallDiscardReasonDeclined",
    "CallDiscardReasonDisconnected",
    "CallDiscardReasonEmpty",
    "CallDiscardReasonHungUp",
    "CallDiscardReasonMissed",
    "CallId",
    "CallProblem",
    "CallProblemDistortedSpeech",
    "CallProblemDistortedVideo",
    "CallProblemDropped",
    "CallProblemEcho",
    "CallProblemInterruptions",
    "CallProblemNoise",
    "CallProblemPixelatedVideo",
    "CallProblemSilentLocal",
    "CallProblemSilentRemote",
    "CallProtocol",
    "CallServer",
    "CallServerType",
    "CallServerTypeTelegramReflector",
    "CallServerTypeWebrtc",
    "CallState",
    "CallStateDiscarded",
    "CallStateError",
    "CallStateExchangingKeys",
    "CallStateHangingUp",
    "CallStatePending",
    "CallStateReady",
    "CallbackQueryAnswer",
    "CallbackQueryPayload",
    "CallbackQueryPayloadData",
    "CallbackQueryPayloadDataWithPassword",
    "CallbackQueryPayloadGame",
    "CanTransferOwnershipResult",
    "CanTransferOwnershipResultOk",
    "CanTransferOwnershipResultPasswordNeeded",
    "CanTransferOwnershipResultPasswordTooFresh",
    "CanTransferOwnershipResultSessionTooFresh",
    "Chat",
    "ChatAction",
    "ChatActionCancel",
    "ChatActionChoosingContact",
    "ChatActionChoosingLocation",
    "ChatActionRecordingVideo",
    "ChatActionRecordingVideoNote",
    "ChatActionRecordingVoiceNote",
    "ChatActionStartPlayingGame",
    "ChatActionTyping",
    "ChatActionUploadingDocument",
    "ChatActionUploadingPhoto",
    "ChatActionUploadingVideo",
    "ChatActionUploadingVideoNote",
    "ChatActionUploadingVoiceNote",
    "ChatActionBar",
    "ChatActionBarAddContact",
    "ChatActionBarInviteMembers",
    "ChatActionBarReportAddBlock",
    "ChatActionBarReportSpam",
    "ChatActionBarReportUnrelatedLocation",
    "ChatActionBarSharePhoneNumber",
    "ChatAdministrator",
    "ChatAdministrators",
    "ChatEvent",
    "ChatEventAction",
    "ChatEventDescriptionChanged",
    "ChatEventInviteLinkDeleted",
    "ChatEventInviteLinkEdited",
    "ChatEventInviteLinkRevoked",
    "ChatEventInvitesToggled",
    "ChatEventIsAllHistoryAvailableToggled",
    "ChatEventLinkedChatChanged",
    "ChatEventLocationChanged",
    "ChatEventMemberInvited",
    "ChatEventMemberJoined",
    "ChatEventMemberJoinedByInviteLink",
    "ChatEventMemberLeft",
    "ChatEventMemberPromoted",
    "ChatEventMemberRestricted",
    "ChatEventMessageDeleted",
    "ChatEventMessageEdited",
    "ChatEventMessagePinned",
    "ChatEventMessageTtlSettingChanged",
    "ChatEventMessageUnpinned",
    "ChatEventPermissionsChanged",
    "ChatEventPhotoChanged",
    "ChatEventPollStopped",
    "ChatEventSignMessagesToggled",
    "ChatEventSlowModeDelayChanged",
    "ChatEventStickerSetChanged",
    "ChatEventTitleChanged",
    "ChatEventUsernameChanged",
    "ChatEventVoiceChatCreated",
    "ChatEventVoiceChatDiscarded",
    "ChatEventVoiceChatMuteNewParticipantsToggled",
    "ChatEventVoiceChatParticipantIsMutedToggled",
    "ChatEventVoiceChatParticipantVolumeLevelChanged",
    "ChatEventLogFilters",
    "ChatEvents",
    "ChatFilter",
    "ChatFilterInfo",
    "ChatInviteLink",
    "ChatInviteLinkCount",
    "ChatInviteLinkCounts",
    "ChatInviteLinkInfo",
    "ChatInviteLinkMember",
    "ChatInviteLinkMembers",
    "ChatInviteLinks",
    "ChatList",
    "ChatListArchive",
    "ChatListFilter",
    "ChatListMain",
    "ChatLists",
    "ChatLocation",
    "ChatMember",
    "ChatMemberStatus",
    "ChatMemberStatusAdministrator",
    "ChatMemberStatusBanned",
    "ChatMemberStatusCreator",
    "ChatMemberStatusLeft",
    "ChatMemberStatusMember",
    "ChatMemberStatusRestricted",
    "ChatMembers",
    "ChatMembersFilter",
    "ChatMembersFilterAdministrators",
    "ChatMembersFilterBanned",
    "ChatMembersFilterBots",
    "ChatMembersFilterContacts",
    "ChatMembersFilterMembers",
    "ChatMembersFilterMention",
    "ChatMembersFilterRestricted",
    "ChatNearby",
    "ChatNotificationSettings",
    "ChatPermissions",
    "ChatPhoto",
    "ChatPhotoInfo",
    "ChatPhotos",
    "ChatPosition",
    "ChatReportReason",
    "ChatReportReasonChildAbuse",
    "ChatReportReasonCopyright",
    "ChatReportReasonCustom",
    "ChatReportReasonFake",
    "ChatReportReasonPornography",
    "ChatReportReasonSpam",
    "ChatReportReasonUnrelatedLocation",
    "ChatReportReasonViolence",
    "ChatSource",
    "ChatSourceMtprotoProxy",
    "ChatSourcePublicServiceAnnouncement",
    "ChatStatistics",
    "ChatStatisticsChannel",
    "ChatStatisticsSupergroup",
    "ChatStatisticsAdministratorActionsInfo",
    "ChatStatisticsInviterInfo",
    "ChatStatisticsMessageInteractionInfo",
    "ChatStatisticsMessageSenderInfo",
    "ChatType",
    "ChatTypeBasicGroup",
    "ChatTypePrivate",
    "ChatTypeSecret",
    "ChatTypeSupergroup",
    "Chats",
    "ChatsNearby",
    "CheckChatUsernameResult",
    "CheckChatUsernameResultOk",
    "CheckChatUsernameResultPublicChatsTooMuch",
    "CheckChatUsernameResultPublicGroupsUnavailable",
    "CheckChatUsernameResultUsernameInvalid",
    "CheckChatUsernameResultUsernameOccupied",
    "CheckStickerSetNameResult",
    "CheckStickerSetNameResultNameInvalid",
    "CheckStickerSetNameResultNameOccupied",
    "CheckStickerSetNameResultOk",
    "ClosedVectorPath",
    "ConnectedWebsite",
    "ConnectedWebsites",
    "ConnectionState",
    "ConnectionStateConnecting",
    "ConnectionStateConnectingToProxy",
    "ConnectionStateReady",
    "ConnectionStateUpdating",
    "ConnectionStateWaitingForNetwork",
    "Contact",
    "Count",
    "Countries",
    "CountryInfo",
    "CustomRequestResult",
    "DatabaseStatistics",
    "Date",
    "DateRange",
    "DatedFile",
    "DeepLinkInfo",
    "DeviceToken",
    "DeviceTokenApplePush",
    "DeviceTokenApplePushVoIP",
    "DeviceTokenBlackBerryPush",
    "DeviceTokenFirebaseCloudMessaging",
    "DeviceTokenMicrosoftPush",
    "DeviceTokenMicrosoftPushVoIP",
    "DeviceTokenSimplePush",
    "DeviceTokenTizenPush",
    "DeviceTokenUbuntuPush",
    "DeviceTokenWebPush",
    "DeviceTokenWindowsPush",
    "DiceStickers",
    "DiceStickersRegular",
    "DiceStickersSlotMachine",
    "Document",
    "DraftMessage",
    "EmailAddressAuthenticationCodeInfo",
    "Emojis",
    "EncryptedCredentials",
    "EncryptedPassportElement",
    "Error",
    "File",
    "FilePart",
    "FileType",
    "FileTypeAnimation",
    "FileTypeAudio",
    "FileTypeDocument",
    "FileTypeNone",
    "FileTypePhoto",
    "FileTypeProfilePhoto",
    "FileTypeSecret",
    "FileTypeSecretThumbnail",
    "FileTypeSecure",
    "FileTypeSticker",
    "FileTypeThumbnail",
    "FileTypeUnknown",
    "FileTypeVideo",
    "FileTypeVideoNote",
    "FileTypeVoiceNote",
    "FileTypeWallpaper",
    "FormattedText",
    "FoundMessages",
    "Game",
    "GameHighScore",
    "GameHighScores",
    "GroupCall",
    "GroupCallId",
    "GroupCallParticipant",
    "GroupCallParticipantVideoInfo",
    "GroupCallRecentSpeaker",
    "GroupCallVideoSourceGroup",
    "Hashtags",
    "HttpUrl",
    "IdentityDocument",
    "ImportedContacts",
    "InlineKeyboardButton",
    "InlineKeyboardButtonType",
    "InlineKeyboardButtonTypeBuy",
    "InlineKeyboardButtonTypeCallback",
    "InlineKeyboardButtonTypeCallbackGame",
    "InlineKeyboardButtonTypeCallbackWithPassword",
    "InlineKeyboardButtonTypeLoginUrl",
    "InlineKeyboardButtonTypeSwitchInline",
    "InlineKeyboardButtonTypeUrl",
    "InlineQueryResult",
    "InlineQueryResultAnimation",
    "InlineQueryResultArticle",
    "InlineQueryResultAudio",
    "InlineQueryResultContact",
    "InlineQueryResultDocument",
    "InlineQueryResultGame",
    "InlineQueryResultLocation",
    "InlineQueryResultPhoto",
    "InlineQueryResultSticker",
    "InlineQueryResultVenue",
    "InlineQueryResultVideo",
    "InlineQueryResultVoiceNote",
    "InlineQueryResults",
    "InputBackground",
    "InputBackgroundLocal",
    "InputBackgroundRemote",
    "InputChatPhoto",
    "InputChatPhotoAnimation",
    "InputChatPhotoPrevious",
    "InputChatPhotoStatic",
    "InputCredentials",
    "InputCredentialsApplePay",
    "InputCredentialsGooglePay",
    "InputCredentialsNew",
    "InputCredentialsSaved",
    "InputFile",
    "InputFileGenerated",
    "InputFileId",
    "InputFileLocal",
    "InputFileRemote",
    "InputIdentityDocument",
    "InputInlineQueryResult",
    "InputInlineQueryResultAnimation",
    "InputInlineQueryResultArticle",
    "InputInlineQueryResultAudio",
    "InputInlineQueryResultContact",
    "InputInlineQueryResultDocument",
    "InputInlineQueryResultGame",
    "InputInlineQueryResultLocation",
    "InputInlineQueryResultPhoto",
    "InputInlineQueryResultSticker",
    "InputInlineQueryResultVenue",
    "InputInlineQueryResultVideo",
    "InputInlineQueryResultVoiceNote",
    "InputMessageContent",
    "InputMessageAnimation",
    "InputMessageAudio",
    "InputMessageContact",
    "InputMessageDice",
    "InputMessageDocument",
    "InputMessageForwarded",
    "InputMessageGame",
    "InputMessageInvoice",
    "InputMessageLocation",
    "InputMessagePhoto",
    "InputMessagePoll",
    "InputMessageSticker",
    "InputMessageText",
    "InputMessageVenue",
    "InputMessageVideo",
    "InputMessageVideoNote",
    "InputMessageVoiceNote",
    "InputPassportElement",
    "InputPassportElementAddress",
    "InputPassportElementBankStatement",
    "InputPassportElementDriverLicense",
    "InputPassportElementEmailAddress",
    "InputPassportElementIdentityCard",
    "InputPassportElementInternalPassport",
    "InputPassportElementPassport",
    "InputPassportElementPassportRegistration",
    "InputPassportElementPersonalDetails",
    "InputPassportElementPhoneNumber",
    "InputPassportElementRentalAgreement",
    "InputPassportElementTemporaryRegistration",
    "InputPassportElementUtilityBill",
    "InputPassportElementError",
    "InputPassportElementErrorSource",
    "InputPassportElementErrorSourceDataField",
    "InputPassportElementErrorSourceFile",
    "InputPassportElementErrorSourceFiles",
    "InputPassportElementErrorSourceFrontSide",
    "InputPassportElementErrorSourceReverseSide",
    "InputPassportElementErrorSourceSelfie",
    "InputPassportElementErrorSourceTranslationFile",
    "InputPassportElementErrorSourceTranslationFiles",
    "InputPassportElementErrorSourceUnspecified",
    "InputPersonalDocument",
    "InputSticker",
    "InputStickerAnimated",
    "InputStickerStatic",
    "InputThumbnail",
    "InternalLinkType",
    "InternalLinkTypeActiveSessions",
    "InternalLinkTypeAuthenticationCode",
    "InternalLinkTypeBackground",
    "InternalLinkTypeBotStart",
    "InternalLinkTypeBotStartInGroup",
    "InternalLinkTypeChangePhoneNumber",
    "InternalLinkTypeChatInvite",
    "InternalLinkTypeFilterSettings",
    "InternalLinkTypeGame",
    "InternalLinkTypeLanguagePack",
    "InternalLinkTypeMessage",
    "InternalLinkTypeMessageDraft",
    "InternalLinkTypePassportDataRequest",
    "InternalLinkTypePhoneNumberConfirmation",
    "InternalLinkTypeProxy",
    "InternalLinkTypePublicChat",
    "InternalLinkTypeQrCodeAuthentication",
    "InternalLinkTypeSettings",
    "InternalLinkTypeStickerSet",
    "InternalLinkTypeTheme",
    "InternalLinkTypeThemeSettings",
    "InternalLinkTypeUnknownDeepLink",
    "InternalLinkTypeVoiceChat",
    "Invoice",
    "JsonValue",
    "JsonValueArray",
    "JsonValueBoolean",
    "JsonValueNull",
    "JsonValueNumber",
    "JsonValueObject",
    "JsonValueString",
    "JsonObjectMember",
    "KeyboardButton",
    "KeyboardButtonType",
    "KeyboardButtonTypeRequestLocation",
    "KeyboardButtonTypeRequestPhoneNumber",
    "KeyboardButtonTypeRequestPoll",
    "KeyboardButtonTypeText",
    "LabeledPricePart",
    "LanguagePackInfo",
    "LanguagePackString",
    "LanguagePackStringValue",
    "LanguagePackStringValueDeleted",
    "LanguagePackStringValueOrdinary",
    "LanguagePackStringValuePluralized",
    "LanguagePackStrings",
    "LocalFile",
    "LocalizationTargetInfo",
    "Location",
    "LogStream",
    "LogStreamDefault",
    "LogStreamEmpty",
    "LogStreamFile",
    "LogTags",
    "LogVerbosityLevel",
    "LoginUrlInfo",
    "LoginUrlInfoOpen",
    "LoginUrlInfoRequestConfirmation",
    "MaskPoint",
    "MaskPointChin",
    "MaskPointEyes",
    "MaskPointForehead",
    "MaskPointMouth",
    "MaskPosition",
    "Message",
    "MessageContent",
    "MessageAnimation",
    "MessageAudio",
    "MessageBasicGroupChatCreate",
    "MessageCall",
    "MessageChatAddMembers",
    "MessageChatChangePhoto",
    "MessageChatChangeTitle",
    "MessageChatDeleteMember",
    "MessageChatDeletePhoto",
    "MessageChatJoinByLink",
    "MessageChatSetTtl",
    "MessageChatUpgradeFrom",
    "MessageChatUpgradeTo",
    "MessageContact",
    "MessageContactRegistered",
    "MessageCustomServiceAction",
    "MessageDice",
    "MessageDocument",
    "MessageExpiredPhoto",
    "MessageExpiredVideo",
    "MessageGame",
    "MessageGameScore",
    "MessageInviteVoiceChatParticipants",
    "MessageInvoice",
    "MessageLocation",
    "MessagePassportDataReceived",
    "MessagePassportDataSent",
    "MessagePaymentSuccessful",
    "MessagePaymentSuccessfulBot",
    "MessagePhoto",
    "MessagePinMessage",
    "MessagePoll",
    "MessageProximityAlertTriggered",
    "MessageScreenshotTaken",
    "MessageSticker",
    "MessageSupergroupChatCreate",
    "MessageText",
    "MessageUnsupported",
    "MessageVenue",
    "MessageVideo",
    "MessageVideoNote",
    "MessageVoiceChatEnded",
    "MessageVoiceChatScheduled",
    "MessageVoiceChatStarted",
    "MessageVoiceNote",
    "MessageWebsiteConnected",
    "MessageCopyOptions",
    "MessageFileType",
    "MessageFileTypeGroup",
    "MessageFileTypePrivate",
    "MessageFileTypeUnknown",
    "MessageForwardInfo",
    "MessageForwardOrigin",
    "MessageForwardOriginChannel",
    "MessageForwardOriginChat",
    "MessageForwardOriginHiddenUser",
    "MessageForwardOriginMessageImport",
    "MessageForwardOriginUser",
    "MessageInteractionInfo",
    "MessageLink",
    "MessageLinkInfo",
    "MessageReplyInfo",
    "MessageSchedulingState",
    "MessageSchedulingStateSendAtDate",
    "MessageSchedulingStateSendWhenOnline",
    "MessageSendOptions",
    "MessageSender",
    "MessageSenderChat",
    "MessageSenderUser",
    "MessageSenders",
    "MessageSendingState",
    "MessageSendingStateFailed",
    "MessageSendingStatePending",
    "MessageStatistics",
    "MessageThreadInfo",
    "Messages",
    "Minithumbnail",
    "NetworkStatistics",
    "NetworkStatisticsEntry",
    "NetworkStatisticsEntryCall",
    "NetworkStatisticsEntryFile",
    "NetworkType",
    "NetworkTypeMobile",
    "NetworkTypeMobileRoaming",
    "NetworkTypeNone",
    "NetworkTypeOther",
    "NetworkTypeWiFi",
    "Notification",
    "NotificationGroup",
    "NotificationGroupType",
    "NotificationGroupTypeCalls",
    "NotificationGroupTypeMentions",
    "NotificationGroupTypeMessages",
    "NotificationGroupTypeSecretChat",
    "NotificationSettingsScope",
    "NotificationSettingsScopeChannelChats",
    "NotificationSettingsScopeGroupChats",
    "NotificationSettingsScopePrivateChats",
    "NotificationType",
    "NotificationTypeNewCall",
    "NotificationTypeNewMessage",
    "NotificationTypeNewPushMessage",
    "NotificationTypeNewSecretChat",
    "Ok",
    "OptionValue",
    "OptionValueBoolean",
    "OptionValueEmpty",
    "OptionValueInteger",
    "OptionValueString",
    "OrderInfo",
    "PageBlock",
    "PageBlockAnchor",
    "PageBlockAnimation",
    "PageBlockAudio",
    "PageBlockAuthorDate",
    "PageBlockBlockQuote",
    "PageBlockChatLink",
    "PageBlockCollage",
    "PageBlockCover",
    "PageBlockDetails",
    "PageBlockDivider",
    "PageBlockEmbedded",
    "PageBlockEmbeddedPost",
    "PageBlockFooter",
    "PageBlockHeader",
    "PageBlockKicker",
    "PageBlockList",
    "PageBlockMap",
    "PageBlockParagraph",
    "PageBlockPhoto",
    "PageBlockPreformatted",
    "PageBlockPullQuote",
    "PageBlockRelatedArticles",
    "PageBlockSlideshow",
    "PageBlockSubheader",
    "PageBlockSubtitle",
    "PageBlockTable",
    "PageBlockTitle",
    "PageBlockVideo",
    "PageBlockVoiceNote",
    "PageBlockListItem",
    "PageBlockCaption",
    "PageBlockHorizontalAlignment",
    "PageBlockHorizontalAlignmentCenter",
    "PageBlockHorizontalAlignmentLeft",
    "PageBlockHorizontalAlignmentRight",
    "PageBlockRelatedArticle",
    "PageBlockTableCell",
    "PageBlockVerticalAlignment",
    "PageBlockVerticalAlignmentBottom",
    "PageBlockVerticalAlignmentMiddle",
    "PageBlockVerticalAlignmentTop",
    "PassportAuthorizationForm",
    "PassportElement",
    "PassportElementAddress",
    "PassportElementBankStatement",
    "PassportElementDriverLicense",
    "PassportElementEmailAddress",
    "PassportElementIdentityCard",
    "PassportElementInternalPassport",
    "PassportElementPassport",
    "PassportElementPassportRegistration",
    "PassportElementPersonalDetails",
    "PassportElementPhoneNumber",
    "PassportElementRentalAgreement",
    "PassportElementTemporaryRegistration",
    "PassportElementUtilityBill",
    "PassportElementError",
    "PassportElementErrorSource",
    "PassportElementErrorSourceDataField",
    "PassportElementErrorSourceFile",
    "PassportElementErrorSourceFiles",
    "PassportElementErrorSourceFrontSide",
    "PassportElementErrorSourceReverseSide",
    "PassportElementErrorSourceSelfie",
    "PassportElementErrorSourceTranslationFile",
    "PassportElementErrorSourceTranslationFiles",
    "PassportElementErrorSourceUnspecified",
    "PassportElementType",
    "PassportElementTypeAddress",
    "PassportElementTypeBankStatement",
    "PassportElementTypeDriverLicense",
    "PassportElementTypeEmailAddress",
    "PassportElementTypeIdentityCard",
    "PassportElementTypeInternalPassport",
    "PassportElementTypePassport",
    "PassportElementTypePassportRegistration",
    "PassportElementTypePersonalDetails",
    "PassportElementTypePhoneNumber",
    "PassportElementTypeRentalAgreement",
    "PassportElementTypeTemporaryRegistration",
    "PassportElementTypeUtilityBill",
    "PassportElements",
    "PassportElementsWithErrors",
    "PassportRequiredElement",
    "PassportSuitableElement",
    "PasswordState",
    "PaymentForm",
    "PaymentFormTheme",
    "PaymentReceipt",
    "PaymentResult",
    "PaymentsProviderStripe",
    "PersonalDetails",
    "PersonalDocument",
    "PhoneNumberAuthenticationSettings",
    "PhoneNumberInfo",
    "Photo",
    "PhotoSize",
    "Point",
    "Poll",
    "PollOption",
    "PollType",
    "PollTypeQuiz",
    "PollTypeRegular",
    "ProfilePhoto",
    "Proxies",
    "Proxy",
    "ProxyType",
    "ProxyTypeHttp",
    "ProxyTypeMtproto",
    "ProxyTypeSocks5",
    "PublicChatType",
    "PublicChatTypeHasUsername",
    "PublicChatTypeIsLocationBased",
    "PushMessageContent",
    "PushMessageContentAnimation",
    "PushMessageContentAudio",
    "PushMessageContentBasicGroupChatCreate",
    "PushMessageContentChatAddMembers",
    "PushMessageContentChatChangePhoto",
    "PushMessageContentChatChangeTitle",
    "PushMessageContentChatDeleteMember",
    "PushMessageContentChatJoinByLink",
    "PushMessageContentContact",
    "PushMessageContentContactRegistered",
    "PushMessageContentDocument",
    "PushMessageContentGame",
    "PushMessageContentGameScore",
    "PushMessageContentHidden",
    "PushMessageContentInvoice",
    "PushMessageContentLocation",
    "PushMessageContentMediaAlbum",
    "PushMessageContentMessageForwards",
    "PushMessageContentPhoto",
    "PushMessageContentPoll",
    "PushMessageContentScreenshotTaken",
    "PushMessageContentSticker",
    "PushMessageContentText",
    "PushMessageContentVideo",
    "PushMessageContentVideoNote",
    "PushMessageContentVoiceNote",
    "PushReceiverId",
    "RecommendedChatFilter",
    "RecommendedChatFilters",
    "RecoveryEmailAddress",
    "RemoteFile",
    "ReplyMarkup",
    "ReplyMarkupForceReply",
    "ReplyMarkupInlineKeyboard",
    "ReplyMarkupRemoveKeyboard",
    "ReplyMarkupShowKeyboard",
    "ResetPasswordResult",
    "ResetPasswordResultDeclined",
    "ResetPasswordResultOk",
    "ResetPasswordResultPending",
    "RichText",
    "RichTextAnchor",
    "RichTextAnchorLink",
    "RichTextBold",
    "RichTextEmailAddress",
    "RichTextFixed",
    "RichTextIcon",
    "RichTextItalic",
    "RichTextMarked",
    "RichTextPhoneNumber",
    "RichTextPlain",
    "RichTextReference",
    "RichTextStrikethrough",
    "RichTextSubscript",
    "RichTextSuperscript",
    "RichTextUnderline",
    "RichTextUrl",
    "RichTexts",
    "SavedCredentials",
    "ScopeNotificationSettings",
    "SearchMessagesFilter",
    "SearchMessagesFilterAnimation",
    "SearchMessagesFilterAudio",
    "SearchMessagesFilterCall",
    "SearchMessagesFilterChatPhoto",
    "SearchMessagesFilterDocument",
    "SearchMessagesFilterEmpty",
    "SearchMessagesFilterFailedToSend",
    "SearchMessagesFilterMention",
    "SearchMessagesFilterMissedCall",
    "SearchMessagesFilterPhoto",
    "SearchMessagesFilterPhotoAndVideo",
    "SearchMessagesFilterPinned",
    "SearchMessagesFilterUnreadMention",
    "SearchMessagesFilterUrl",
    "SearchMessagesFilterVideo",
    "SearchMessagesFilterVideoNote",
    "SearchMessagesFilterVoiceAndVideoNote",
    "SearchMessagesFilterVoiceNote",
    "Seconds",
    "SecretChat",
    "SecretChatState",
    "SecretChatStateClosed",
    "SecretChatStatePending",
    "SecretChatStateReady",
    "Session",
    "Sessions",
    "ShippingOption",
    "StatisticalGraph",
    "StatisticalGraphAsync",
    "StatisticalGraphData",
    "StatisticalGraphError",
    "StatisticalValue",
    "Sticker",
    "StickerSet",
    "StickerSetInfo",
    "StickerSets",
    "Stickers",
    "StorageStatistics",
    "StorageStatisticsByChat",
    "StorageStatisticsByFileType",
    "StorageStatisticsFast",
    "SuggestedAction",
    "SuggestedActionCheckPassword",
    "SuggestedActionCheckPhoneNumber",
    "SuggestedActionConvertToBroadcastGroup",
    "SuggestedActionEnableArchiveAndMuteNewChats",
    "SuggestedActionSeeTicksHint",
    "Supergroup",
    "SupergroupFullInfo",
    "SupergroupMembersFilter",
    "SupergroupMembersFilterAdministrators",
    "SupergroupMembersFilterBanned",
    "SupergroupMembersFilterBots",
    "SupergroupMembersFilterContacts",
    "SupergroupMembersFilterMention",
    "SupergroupMembersFilterRecent",
    "SupergroupMembersFilterRestricted",
    "SupergroupMembersFilterSearch",
    "TMeUrl",
    "TMeUrlType",
    "TMeUrlTypeChatInvite",
    "TMeUrlTypeStickerSet",
    "TMeUrlTypeSupergroup",
    "TMeUrlTypeUser",
    "TMeUrls",
    "TdlibParameters",
    "TemporaryPasswordState",
    "TermsOfService",
    "TestBytes",
    "TestInt",
    "TestString",
    "TestVectorInt",
    "TestVectorIntObject",
    "TestVectorString",
    "TestVectorStringObject",
    "Text",
    "TextEntities",
    "TextEntity",
    "TextEntityType",
    "TextEntityTypeBankCardNumber",
    "TextEntityTypeBold",
    "TextEntityTypeBotCommand",
    "TextEntityTypeCashtag",
    "TextEntityTypeCode",
    "TextEntityTypeEmailAddress",
    "TextEntityTypeHashtag",
    "TextEntityTypeItalic",
    "TextEntityTypeMention",
    "TextEntityTypeMentionName",
    "TextEntityTypePhoneNumber",
    "TextEntityTypePre",
    "TextEntityTypePreCode",
    "TextEntityTypeStrikethrough",
    "TextEntityTypeTextUrl",
    "TextEntityTypeUnderline",
    "TextEntityTypeUrl",
    "TextParseMode",
    "TextParseModeHTML",
    "TextParseModeMarkdown",
    "Thumbnail",
    "ThumbnailFormat",
    "ThumbnailFormatGif",
    "ThumbnailFormatJpeg",
    "ThumbnailFormatMpeg4",
    "ThumbnailFormatPng",
    "ThumbnailFormatTgs",
    "ThumbnailFormatWebp",
    "TopChatCategory",
    "TopChatCategoryBots",
    "TopChatCategoryCalls",
    "TopChatCategoryChannels",
    "TopChatCategoryForwardChats",
    "TopChatCategoryGroups",
    "TopChatCategoryInlineBots",
    "TopChatCategoryUsers",
    "Update",
    "UpdateActiveNotifications",
    "UpdateAnimationSearchParameters",
    "UpdateAuthorizationState",
    "UpdateBasicGroup",
    "UpdateBasicGroupFullInfo",
    "UpdateCall",
    "UpdateChatActionBar",
    "UpdateChatDefaultDisableNotification",
    "UpdateChatDraftMessage",
    "UpdateChatFilters",
    "UpdateChatHasScheduledMessages",
    "UpdateChatIsBlocked",
    "UpdateChatIsMarkedAsUnread",
    "UpdateChatLastMessage",
    "UpdateChatMember",
    "UpdateChatMessageTtlSetting",
    "UpdateChatNotificationSettings",
    "UpdateChatOnlineMemberCount",
    "UpdateChatPermissions",
    "UpdateChatPhoto",
    "UpdateChatPosition",
    "UpdateChatReadInbox",
    "UpdateChatReadOutbox",
    "UpdateChatReplyMarkup",
    "UpdateChatTitle",
    "UpdateChatUnreadMentionCount",
    "UpdateChatVoiceChat",
    "UpdateConnectionState",
    "UpdateDeleteMessages",
    "UpdateDiceEmojis",
    "UpdateFavoriteStickers",
    "UpdateFile",
    "UpdateFileGenerationStart",
    "UpdateFileGenerationStop",
    "UpdateGroupCall",
    "UpdateGroupCallParticipant",
    "UpdateHavePendingNotifications",
    "UpdateInstalledStickerSets",
    "UpdateLanguagePackStrings",
    "UpdateMessageContent",
    "UpdateMessageContentOpened",
    "UpdateMessageEdited",
    "UpdateMessageInteractionInfo",
    "UpdateMessageIsPinned",
    "UpdateMessageLiveLocationViewed",
    "UpdateMessageMentionRead",
    "UpdateMessageSendAcknowledged",
    "UpdateMessageSendFailed",
    "UpdateMessageSendSucceeded",
    "UpdateNewCallSignalingData",
    "UpdateNewCallbackQuery",
    "UpdateNewChat",
    "UpdateNewChosenInlineResult",
    "UpdateNewCustomEvent",
    "UpdateNewCustomQuery",
    "UpdateNewInlineCallbackQuery",
    "UpdateNewInlineQuery",
    "UpdateNewMessage",
    "UpdateNewPreCheckoutQuery",
    "UpdateNewShippingQuery",
    "UpdateNotification",
    "UpdateNotificationGroup",
    "UpdateOption",
    "UpdatePoll",
    "UpdatePollAnswer",
    "UpdateRecentStickers",
    "UpdateSavedAnimations",
    "UpdateScopeNotificationSettings",
    "UpdateSecretChat",
    "UpdateSelectedBackground",
    "UpdateServiceNotification",
    "UpdateStickerSet",
    "UpdateSuggestedActions",
    "UpdateSupergroup",
    "UpdateSupergroupFullInfo",
    "UpdateTermsOfService",
    "UpdateTrendingStickerSets",
    "UpdateUnreadChatCount",
    "UpdateUnreadMessageCount",
    "UpdateUser",
    "UpdateUserChatAction",
    "UpdateUserFullInfo",
    "UpdateUserPrivacySettingRules",
    "UpdateUserStatus",
    "UpdateUsersNearby",
    "Updates",
    "User",
    "UserFullInfo",
    "UserPrivacySetting",
    "UserPrivacySettingAllowCalls",
    "UserPrivacySettingAllowChatInvites",
    "UserPrivacySettingAllowFindingByPhoneNumber",
    "UserPrivacySettingAllowPeerToPeerCalls",
    "UserPrivacySettingShowLinkInForwardedMessages",
    "UserPrivacySettingShowPhoneNumber",
    "UserPrivacySettingShowProfilePhoto",
    "UserPrivacySettingShowStatus",
    "UserPrivacySettingRule",
    "UserPrivacySettingRuleAllowAll",
    "UserPrivacySettingRuleAllowChatMembers",
    "UserPrivacySettingRuleAllowContacts",
    "UserPrivacySettingRuleAllowUsers",
    "UserPrivacySettingRuleRestrictAll",
    "UserPrivacySettingRuleRestrictChatMembers",
    "UserPrivacySettingRuleRestrictContacts",
    "UserPrivacySettingRuleRestrictUsers",
    "UserPrivacySettingRules",
    "UserStatus",
    "UserStatusEmpty",
    "UserStatusLastMonth",
    "UserStatusLastWeek",
    "UserStatusOffline",
    "UserStatusOnline",
    "UserStatusRecently",
    "UserType",
    "UserTypeBot",
    "UserTypeDeleted",
    "UserTypeRegular",
    "UserTypeUnknown",
    "Users",
    "ValidatedOrderInfo",
    "VectorPathCommand",
    "VectorPathCommandCubicBezierCurve",
    "VectorPathCommandLine",
    "Venue",
    "Video",
    "VideoNote",
    "VoiceChat",
    "VoiceNote",
    "WebPage",
    "WebPageInstantView",
]



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .file import File
from .minithumbnail import Minithumbnail
from .thumbnail import Thumbnail
from ..base_object import BaseObject


class VideoNote(BaseObject):
    """
    Describes a video note. The video must be equal in width and height, cropped to a circle, and stored in MPEG4 format
    
    Params:
        duration (:class:`int`)
            Duration of the video, in seconds; as defined by the sender
        
        length (:class:`int`)
            Video width and height; as defined by the sender
        
        minithumbnail (:class:`Minithumbnail`)
            Video minithumbnail; may be null
        
        thumbnail (:class:`Thumbnail`)
            Video thumbnail in JPEG format; as defined by the sender; may be null
        
        video (:class:`File`)
            File containing the video
        
    """

    ID: str = Field("videoNote", alias="@type")
    duration: int
    length: int
    minithumbnail: typing.Optional[Minithumbnail] = None
    thumbnail: typing.Optional[Thumbnail] = None
    video: File

    @staticmethod
    def read(q: dict) -> VideoNote:
        return VideoNote.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import SupergroupMembersFilter


class GetSupergroupMembers(BaseObject):
    """
    Returns information about members or banned users in a supergroup or channel. Can be used only if SupergroupFullInfo.can_get_members == true; additionally, administrator privileges may be required for some filters
    
    Params:
        supergroup_id (:class:`int`)
            Identifier of the supergroup or channel
        
        filter_ (:class:`SupergroupMembersFilter`)
            The type of users to return. By default, supergroupMembersFilterRecent
        
        offset (:class:`int`)
            Number of users to skip
        
        limit (:class:`int`)
            The maximum number of users be returned; up to 200
        
    """

    ID: str = Field("getSupergroupMembers", alias="@type")
    supergroup_id: int
    filter_: SupergroupMembersFilter = Field(..., alias='filter')
    offset: int
    limit: int

    @staticmethod
    def read(q: dict) -> GetSupergroupMembers:
        return GetSupergroupMembers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import PassportElementType


class GetPassportElement(BaseObject):
    """
    Returns one of the available Telegram Passport elements
    
    Params:
        type_ (:class:`PassportElementType`)
            Telegram Passport element type
        
        password (:class:`str`)
            Password of the current user
        
    """

    ID: str = Field("getPassportElement", alias="@type")
    type_: PassportElementType = Field(..., alias='type')
    password: str

    @staticmethod
    def read(q: dict) -> GetPassportElement:
        return GetPassportElement.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .point import Point
from ..base_object import BaseObject


class VectorPathCommand(BaseObject):
    """
    Represents a vector path command
    
    """

    ID: str = Field("vectorPathCommand", alias="@type")


class VectorPathCommandCubicBezierCurve(VectorPathCommand):
    """
    A cubic Bézier curve to a given point
    
    Params:
        start_control_point (:class:`Point`)
            The start control point of the curve
        
        end_control_point (:class:`Point`)
            The end control point of the curve
        
        end_point (:class:`Point`)
            The end point of the curve
        
    """

    ID: str = Field("vectorPathCommandCubicBezierCurve", alias="@type")
    start_control_point: Point
    end_control_point: Point
    end_point: Point

    @staticmethod
    def read(q: dict) -> VectorPathCommandCubicBezierCurve:
        return VectorPathCommandCubicBezierCurve.construct(**q)


class VectorPathCommandLine(VectorPathCommand):
    """
    A straight line to a given point
    
    Params:
        end_point (:class:`Point`)
            The end point of the straight line
        
    """

    ID: str = Field("vectorPathCommandLine", alias="@type")
    end_point: Point

    @staticmethod
    def read(q: dict) -> VectorPathCommandLine:
        return VectorPathCommandLine.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SendBotStartMessage(BaseObject):
    """
    Invites a bot to a chat (if it is not yet a member) and sends it the /start command. Bots can't be invited to a private chat other than the chat with the bot. Bots can't be invited to channels (although they can be added as admins) and secret chats. Returns the sent message
    
    Params:
        bot_user_id (:class:`int`)
            Identifier of the bot
        
        chat_id (:class:`int`)
            Identifier of the target chat
        
        parameter (:class:`str`)
            A hidden parameter sent to the bot for deep linking purposes (https://core.telegram.org/bots#deep-linking)
        
    """

    ID: str = Field("sendBotStartMessage", alias="@type")
    bot_user_id: int
    chat_id: int
    parameter: str

    @staticmethod
    def read(q: dict) -> SendBotStartMessage:
        return SendBotStartMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatFilter


class CreateChatFilter(BaseObject):
    """
    Creates new chat filter. Returns information about the created chat filter
    
    Params:
        filter_ (:class:`ChatFilter`)
            Chat filter
        
    """

    ID: str = Field("createChatFilter", alias="@type")
    filter_: ChatFilter = Field(..., alias='filter')

    @staticmethod
    def read(q: dict) -> CreateChatFilter:
        return CreateChatFilter.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatStatisticsMessageSenderInfo(BaseObject):
    """
    Contains statistics about messages sent by a user
    
    Params:
        user_id (:class:`int`)
            User identifier
        
        sent_message_count (:class:`int`)
            Number of sent messages
        
        average_character_count (:class:`int`)
            Average number of characters in sent messages
        
    """

    ID: str = Field("chatStatisticsMessageSenderInfo", alias="@type")
    user_id: int
    sent_message_count: int
    average_character_count: int

    @staticmethod
    def read(q: dict) -> ChatStatisticsMessageSenderInfo:
        return ChatStatisticsMessageSenderInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DatabaseStatistics(BaseObject):
    """
    Contains database statistics
    
    Params:
        statistics (:class:`str`)
            Database statistics in an unspecified human-readable format
        
    """

    ID: str = Field("databaseStatistics", alias="@type")
    statistics: str

    @staticmethod
    def read(q: dict) -> DatabaseStatistics:
        return DatabaseStatistics.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import MessageSender


class ToggleMessageSenderIsBlocked(BaseObject):
    """
    Changes the block state of a message sender. Currently, only users and supergroup chats can be blocked
    
    Params:
        sender (:class:`MessageSender`)
            Message Sender
        
        is_blocked (:class:`bool`)
            New value of is_blocked
        
    """

    ID: str = Field("toggleMessageSenderIsBlocked", alias="@type")
    sender: MessageSender
    is_blocked: bool

    @staticmethod
    def read(q: dict) -> ToggleMessageSenderIsBlocked:
        return ToggleMessageSenderIsBlocked.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetTrendingStickerSets(BaseObject):
    """
    Returns a list of trending sticker sets. For the optimal performance the number of returned sticker sets is chosen by the library
    
    Params:
        offset (:class:`int`)
            The offset from which to return the sticker sets; must be non-negative
        
        limit (:class:`int`)
            The maximum number of sticker sets to be returned; must be non-negative. Fewer sticker sets may be returned than specified by the limit, even if the end of the list has not been reached
        
    """

    ID: str = Field("getTrendingStickerSets", alias="@type")
    offset: int
    limit: int

    @staticmethod
    def read(q: dict) -> GetTrendingStickerSets:
        return GetTrendingStickerSets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class Error(BaseObject):
    """
    An object of this type can be returned on every function call, in case of an error
    
    Params:
        code (:class:`int`)
            Error code; subject to future changes. If the error code is 406, the error message must not be processed in any way and must not be displayed to the user
        
        message (:class:`str`)
            Error message; subject to future changes
        
    """

    ID: str = Field("error", alias="@type")
    code: int
    message: str

    @staticmethod
    def read(q: dict) -> Error:
        return Error.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class MaskPoint(BaseObject):
    """
    Part of the face, relative to which a mask should be placed
    
    """

    ID: str = Field("maskPoint", alias="@type")


class MaskPointChin(MaskPoint):
    """
    A mask should be placed relatively to the chin
    
    """

    ID: str = Field("maskPointChin", alias="@type")

    @staticmethod
    def read(q: dict) -> MaskPointChin:
        return MaskPointChin.construct(**q)


class MaskPointEyes(MaskPoint):
    """
    A mask should be placed relatively to the eyes
    
    """

    ID: str = Field("maskPointEyes", alias="@type")

    @staticmethod
    def read(q: dict) -> MaskPointEyes:
        return MaskPointEyes.construct(**q)


class MaskPointForehead(MaskPoint):
    """
    A mask should be placed relatively to the forehead
    
    """

    ID: str = Field("maskPointForehead", alias="@type")

    @staticmethod
    def read(q: dict) -> MaskPointForehead:
        return MaskPointForehead.construct(**q)


class MaskPointMouth(MaskPoint):
    """
    A mask should be placed relatively to the mouth
    
    """

    ID: str = Field("maskPointMouth", alias="@type")

    @staticmethod
    def read(q: dict) -> MaskPointMouth:
        return MaskPointMouth.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetPhoneNumberInfo(BaseObject):
    """
    Returns information about a phone number by its prefix. Can be called before authorization
    
    Params:
        phone_number_prefix (:class:`str`)
            The phone number prefix
        
    """

    ID: str = Field("getPhoneNumberInfo", alias="@type")
    phone_number_prefix: str

    @staticmethod
    def read(q: dict) -> GetPhoneNumberInfo:
        return GetPhoneNumberInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ProcessPushNotification(BaseObject):
    """
    Handles a push notification. Returns error with code 406 if the push notification is not supported and connection to the server is required to fetch new data. Can be called before authorization
    
    Params:
        payload (:class:`str`)
            JSON-encoded push notification payload with all fields sent by the server, and "google.sent_time" and "google.notification.sound" fields added
        
    """

    ID: str = Field("processPushNotification", alias="@type")
    payload: str

    @staticmethod
    def read(q: dict) -> ProcessPushNotification:
        return ProcessPushNotification.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class JoinChatByInviteLink(BaseObject):
    """
    Uses an invite link to add the current user to the chat if possible
    
    Params:
        invite_link (:class:`str`)
            Invite link to use
        
    """

    ID: str = Field("joinChatByInviteLink", alias="@type")
    invite_link: str

    @staticmethod
    def read(q: dict) -> JoinChatByInviteLink:
        return JoinChatByInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class BotCommand(BaseObject):
    """
    Represents a command supported by a bot
    
    Params:
        command (:class:`str`)
            Text of the bot command
        
        param_description (:class:`str`)
            Description of the bot command
        
    """

    ID: str = Field("botCommand", alias="@type")
    command: str
    param_description: str

    @staticmethod
    def read(q: dict) -> BotCommand:
        return BotCommand.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatPermissions(BaseObject):
    """
    Describes actions that a user is allowed to take in a chat
    
    Params:
        can_send_messages (:class:`bool`)
            True, if the user can send text messages, contacts, locations, and venues
        
        can_send_media_messages (:class:`bool`)
            True, if the user can send audio files, documents, photos, videos, video notes, and voice notes. Implies can_send_messages permissions
        
        can_send_polls (:class:`bool`)
            True, if the user can send polls. Implies can_send_messages permissions
        
        can_send_other_messages (:class:`bool`)
            True, if the user can send animations, games, stickers, and dice and use inline bots. Implies can_send_messages permissions
        
        can_add_web_page_previews (:class:`bool`)
            True, if the user may add a web page preview to their messages. Implies can_send_messages permissions
        
        can_change_info (:class:`bool`)
            True, if the user can change the chat title, photo, and other settings
        
        can_invite_users (:class:`bool`)
            True, if the user can invite new users to the chat
        
        can_pin_messages (:class:`bool`)
            True, if the user can pin messages
        
    """

    ID: str = Field("chatPermissions", alias="@type")
    can_send_messages: bool
    can_send_media_messages: bool
    can_send_polls: bool
    can_send_other_messages: bool
    can_add_web_page_previews: bool
    can_change_info: bool
    can_invite_users: bool
    can_pin_messages: bool

    @staticmethod
    def read(q: dict) -> ChatPermissions:
        return ChatPermissions.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class UserPrivacySetting(BaseObject):
    """
    Describes available user privacy settings
    
    """

    ID: str = Field("userPrivacySetting", alias="@type")


class UserPrivacySettingAllowCalls(UserPrivacySetting):
    """
    A privacy setting for managing whether the user can be called
    
    """

    ID: str = Field("userPrivacySettingAllowCalls", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingAllowCalls:
        return UserPrivacySettingAllowCalls.construct(**q)


class UserPrivacySettingAllowChatInvites(UserPrivacySetting):
    """
    A privacy setting for managing whether the user can be invited to chats
    
    """

    ID: str = Field("userPrivacySettingAllowChatInvites", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingAllowChatInvites:
        return UserPrivacySettingAllowChatInvites.construct(**q)


class UserPrivacySettingAllowFindingByPhoneNumber(UserPrivacySetting):
    """
    A privacy setting for managing whether the user can be found by their phone number. Checked only if the phone number is not known to the other user. Can be set only to "Allow contacts" or "Allow all"
    
    """

    ID: str = Field("userPrivacySettingAllowFindingByPhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingAllowFindingByPhoneNumber:
        return UserPrivacySettingAllowFindingByPhoneNumber.construct(**q)


class UserPrivacySettingAllowPeerToPeerCalls(UserPrivacySetting):
    """
    A privacy setting for managing whether peer-to-peer connections can be used for calls
    
    """

    ID: str = Field("userPrivacySettingAllowPeerToPeerCalls", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingAllowPeerToPeerCalls:
        return UserPrivacySettingAllowPeerToPeerCalls.construct(**q)


class UserPrivacySettingShowLinkInForwardedMessages(UserPrivacySetting):
    """
    A privacy setting for managing whether a link to the user's account is included in forwarded messages
    
    """

    ID: str = Field("userPrivacySettingShowLinkInForwardedMessages", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingShowLinkInForwardedMessages:
        return UserPrivacySettingShowLinkInForwardedMessages.construct(**q)


class UserPrivacySettingShowPhoneNumber(UserPrivacySetting):
    """
    A privacy setting for managing whether the user's phone number is visible
    
    """

    ID: str = Field("userPrivacySettingShowPhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingShowPhoneNumber:
        return UserPrivacySettingShowPhoneNumber.construct(**q)


class UserPrivacySettingShowProfilePhoto(UserPrivacySetting):
    """
    A privacy setting for managing whether the user's profile photo is visible
    
    """

    ID: str = Field("userPrivacySettingShowProfilePhoto", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingShowProfilePhoto:
        return UserPrivacySettingShowProfilePhoto.construct(**q)


class UserPrivacySettingShowStatus(UserPrivacySetting):
    """
    A privacy setting for managing whether the user's online status is visible
    
    """

    ID: str = Field("userPrivacySettingShowStatus", alias="@type")

    @staticmethod
    def read(q: dict) -> UserPrivacySettingShowStatus:
        return UserPrivacySettingShowStatus.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import BotCommand
from ..types import BotCommandScope


class SetCommands(BaseObject):
    """
    Sets the list of commands supported by the bot for the given user scope and language; for bots only
    
    Params:
        scope (:class:`BotCommandScope`)
            The scope to which the commands are relevant
        
        language_code (:class:`str`)
            A two-letter ISO 639-1 country code. If empty, the commands will be applied to all users from the given scope, for which language there are no dedicated commands
        
        commands (:obj:`list[BotCommand]`)
            List of the bot's commands
        
    """

    ID: str = Field("setCommands", alias="@type")
    scope: BotCommandScope
    language_code: str
    commands: list[BotCommand]

    @staticmethod
    def read(q: dict) -> SetCommands:
        return SetCommands.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ReplyMarkup


class StopPoll(BaseObject):
    """
    Stops a poll. A poll in a message can be stopped when the message has can_be_edited flag set
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat to which the poll belongs
        
        message_id (:class:`int`)
            Identifier of the message containing the poll
        
        reply_markup (:class:`ReplyMarkup`)
            The new message reply markup; for bots only
        
    """

    ID: str = Field("stopPoll", alias="@type")
    chat_id: int
    message_id: int
    reply_markup: ReplyMarkup

    @staticmethod
    def read(q: dict) -> StopPoll:
        return StopPoll.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_invite_link import ChatInviteLink
from ..base_object import BaseObject


class ChatInviteLinks(BaseObject):
    """
    Contains a list of chat invite links
    
    Params:
        total_count (:class:`int`)
            Approximate total count of chat invite links found
        
        invite_links (:obj:`list[ChatInviteLink]`)
            List of invite links
        
    """

    ID: str = Field("chatInviteLinks", alias="@type")
    total_count: int
    invite_links: list[ChatInviteLink]

    @staticmethod
    def read(q: dict) -> ChatInviteLinks:
        return ChatInviteLinks.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SetRecoveryEmailAddress(BaseObject):
    """
    Changes the 2-step verification recovery email address of the user. If a new recovery email address is specified, then the change will not be applied until the new recovery email address is confirmed. If new_recovery_email_address is the same as the email address that is currently set up, this call succeeds immediately and aborts all other requests waiting for an email confirmation
    
    Params:
        password (:class:`str`)
            Password of the current user
        
        new_recovery_email_address (:class:`str`)
            New recovery email address
        
    """

    ID: str = Field("setRecoveryEmailAddress", alias="@type")
    password: str
    new_recovery_email_address: str

    @staticmethod
    def read(q: dict) -> SetRecoveryEmailAddress:
        return SetRecoveryEmailAddress.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetMessageThread(BaseObject):
    """
    Returns information about a message thread. Can be used only if message.can_get_message_thread == true
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        message_id (:class:`int`)
            Identifier of the message
        
    """

    ID: str = Field("getMessageThread", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> GetMessageThread:
        return GetMessageThread.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class OpenMessageContent(BaseObject):
    """
    Informs TDLib that the message content has been opened (e.g., the user has opened a photo, video, document, location or venue, or has listened to an audio file or voice note message). An updateMessageContentOpened update will be generated if something has changed
    
    Params:
        chat_id (:class:`int`)
            Chat identifier of the message
        
        message_id (:class:`int`)
            Identifier of the message with the opened content
        
    """

    ID: str = Field("openMessageContent", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> OpenMessageContent:
        return OpenMessageContent.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .file import File
from .thumbnail_format import ThumbnailFormat
from ..base_object import BaseObject


class Thumbnail(BaseObject):
    """
    Represents a thumbnail
    
    Params:
        format (:class:`ThumbnailFormat`)
            Thumbnail format
        
        width (:class:`int`)
            Thumbnail width
        
        height (:class:`int`)
            Thumbnail height
        
        file (:class:`File`)
            The thumbnail
        
    """

    ID: str = Field("thumbnail", alias="@type")
    format: ThumbnailFormat
    width: int
    height: int
    file: File

    @staticmethod
    def read(q: dict) -> Thumbnail:
        return Thumbnail.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetSupportUser(BaseObject):
    """
    Returns a user that can be contacted to get support
    
    """

    ID: str = Field("getSupportUser", alias="@type")

    @staticmethod
    def read(q: dict) -> GetSupportUser:
        return GetSupportUser.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ToggleGroupCallMuteNewParticipants(BaseObject):
    """
    Toggles whether new participants of a group call can be unmuted only by administrators of the group call. Requires groupCall.can_change_mute_new_participants group call flag
    
    Params:
        group_call_id (:class:`int`)
            Group call identifier
        
        mute_new_participants (:class:`bool`)
            New value of the mute_new_participants setting
        
    """

    ID: str = Field("toggleGroupCallMuteNewParticipants", alias="@type")
    group_call_id: int
    mute_new_participants: bool

    @staticmethod
    def read(q: dict) -> ToggleGroupCallMuteNewParticipants:
        return ToggleGroupCallMuteNewParticipants.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .text_entity import TextEntity
from ..base_object import BaseObject


class TextEntities(BaseObject):
    """
    Contains a list of text entities
    
    Params:
        entities (:obj:`list[TextEntity]`)
            List of text entities
        
    """

    ID: str = Field("textEntities", alias="@type")
    entities: list[TextEntity]

    @staticmethod
    def read(q: dict) -> TextEntities:
        return TextEntities.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .group_call_video_source_group import GroupCallVideoSourceGroup
from ..base_object import BaseObject


class GroupCallParticipantVideoInfo(BaseObject):
    """
    Contains information about a group call participant's video channel
    
    Params:
        source_groups (:obj:`list[GroupCallVideoSourceGroup]`)
            List of synchronization source groups of the video
        
        endpoint_id (:class:`str`)
            Video channel endpoint identifier
        
        is_paused (:class:`bool`)
            True if the video is paused. This flag needs to be ignored, if new video frames are received
        
    """

    ID: str = Field("groupCallParticipantVideoInfo", alias="@type")
    source_groups: list[GroupCallVideoSourceGroup]
    endpoint_id: str
    is_paused: bool

    @staticmethod
    def read(q: dict) -> GroupCallParticipantVideoInfo:
        return GroupCallParticipantVideoInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LogTags(BaseObject):
    """
    Contains a list of available TDLib internal log tags
    
    Params:
        tags (:obj:`list[str]`)
            List of log tags
        
    """

    ID: str = Field("logTags", alias="@type")
    tags: list[str]

    @staticmethod
    def read(q: dict) -> LogTags:
        return LogTags.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .sticker import Sticker
from ..base_object import BaseObject


class Stickers(BaseObject):
    """
    Represents a list of stickers
    
    Params:
        stickers (:obj:`list[Sticker]`)
            List of stickers
        
    """

    ID: str = Field("stickers", alias="@type")
    stickers: list[Sticker]

    @staticmethod
    def read(q: dict) -> Stickers:
        return Stickers.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetAttachedStickerSets(BaseObject):
    """
    Returns a list of sticker sets attached to a file. Currently only photos and videos can have attached sticker sets
    
    Params:
        file_id (:class:`int`)
            File identifier
        
    """

    ID: str = Field("getAttachedStickerSets", alias="@type")
    file_id: int

    @staticmethod
    def read(q: dict) -> GetAttachedStickerSets:
        return GetAttachedStickerSets.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetOption(BaseObject):
    """
    Returns the value of an option by its name. (Check the list of available options on https://core.telegram.org/tdlib/options.) Can be called before authorization
    
    Params:
        name (:class:`str`)
            The name of the option
        
    """

    ID: str = Field("getOption", alias="@type")
    name: str

    @staticmethod
    def read(q: dict) -> GetOption:
        return GetOption.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class UnpinChatMessage(BaseObject):
    """
    Removes a pinned message from a chat; requires can_pin_messages rights in the group or can_edit_messages rights in the channel
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat
        
        message_id (:class:`int`)
            Identifier of the removed pinned message
        
    """

    ID: str = Field("unpinChatMessage", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> UnpinChatMessage:
        return UnpinChatMessage.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatList


class ToggleChatIsPinned(BaseObject):
    """
    Changes the pinned state of a chat. There can be up to GetOption("pinned_chat_count_max")/GetOption("pinned_archived_chat_count_max") pinned non-secret chats and the same number of secret chats in the main/arhive chat list
    
    Params:
        chat_list (:class:`ChatList`)
            Chat list in which to change the pinned state of the chat
        
        chat_id (:class:`int`)
            Chat identifier
        
        is_pinned (:class:`bool`)
            True, if the chat is pinned
        
    """

    ID: str = Field("toggleChatIsPinned", alias="@type")
    chat_list: ChatList
    chat_id: int
    is_pinned: bool

    @staticmethod
    def read(q: dict) -> ToggleChatIsPinned:
        return ToggleChatIsPinned.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class TestVectorInt(BaseObject):
    """
    A simple object containing a vector of numbers; for testing only
    
    Params:
        value (:obj:`list[int]`)
            Vector of numbers
        
    """

    ID: str = Field("testVectorInt", alias="@type")
    value: list[int]

    @staticmethod
    def read(q: dict) -> TestVectorInt:
        return TestVectorInt.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetStorageStatistics(BaseObject):
    """
    Returns storage usage statistics. Can be called before authorization
    
    Params:
        chat_limit (:class:`int`)
            The maximum number of chats with the largest storage usage for which separate statistics should be returned. All other chats will be grouped in entries with chat_id == 0. If the chat info database is not used, the chat_limit is ignored and is always set to 0
        
    """

    ID: str = Field("getStorageStatistics", alias="@type")
    chat_limit: int

    @staticmethod
    def read(q: dict) -> GetStorageStatistics:
        return GetStorageStatistics.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetMessageLocally(BaseObject):
    """
    Returns information about a message, if it is available locally without sending network request. This is an offline request
    
    Params:
        chat_id (:class:`int`)
            Identifier of the chat the message belongs to
        
        message_id (:class:`int`)
            Identifier of the message to get
        
    """

    ID: str = Field("getMessageLocally", alias="@type")
    chat_id: int
    message_id: int

    @staticmethod
    def read(q: dict) -> GetMessageLocally:
        return GetMessageLocally.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .bot_commands import BotCommands
from .chat_invite_link import ChatInviteLink
from .chat_member import ChatMember
from .chat_photo import ChatPhoto
from ..base_object import BaseObject


class BasicGroupFullInfo(BaseObject):
    """
    Contains full information about a basic group
    
    Params:
        photo (:class:`ChatPhoto`)
            Chat photo; may be null
        
        param_description (:class:`str`)
            Group description. Updated only after the basic group is opened
        
        creator_user_id (:class:`int`)
            User identifier of the creator of the group; 0 if unknown
        
        members (:obj:`list[ChatMember]`)
            Group members
        
        invite_link (:class:`ChatInviteLink`)
            Primary invite link for this group; may be null. For chat administrators with can_invite_users right only. Updated only after the basic group is opened
        
        bot_commands (:obj:`list[BotCommands]`)
            List of commands of bots in the group
        
    """

    ID: str = Field("basicGroupFullInfo", alias="@type")
    photo: typing.Optional[ChatPhoto] = None
    param_description: str
    creator_user_id: int
    members: list[ChatMember]
    invite_link: typing.Optional[ChatInviteLink] = None
    bot_commands: list[BotCommands]

    @staticmethod
    def read(q: dict) -> BasicGroupFullInfo:
        return BasicGroupFullInfo.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class PassportElementType(BaseObject):
    """
    Contains the type of a Telegram Passport element
    
    """

    ID: str = Field("passportElementType", alias="@type")


class PassportElementTypeAddress(PassportElementType):
    """
    A Telegram Passport element containing the user's address
    
    """

    ID: str = Field("passportElementTypeAddress", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeAddress:
        return PassportElementTypeAddress.construct(**q)


class PassportElementTypeBankStatement(PassportElementType):
    """
    A Telegram Passport element containing the user's bank statement
    
    """

    ID: str = Field("passportElementTypeBankStatement", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeBankStatement:
        return PassportElementTypeBankStatement.construct(**q)


class PassportElementTypeDriverLicense(PassportElementType):
    """
    A Telegram Passport element containing the user's driver license
    
    """

    ID: str = Field("passportElementTypeDriverLicense", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeDriverLicense:
        return PassportElementTypeDriverLicense.construct(**q)


class PassportElementTypeEmailAddress(PassportElementType):
    """
    A Telegram Passport element containing the user's email address
    
    """

    ID: str = Field("passportElementTypeEmailAddress", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeEmailAddress:
        return PassportElementTypeEmailAddress.construct(**q)


class PassportElementTypeIdentityCard(PassportElementType):
    """
    A Telegram Passport element containing the user's identity card
    
    """

    ID: str = Field("passportElementTypeIdentityCard", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeIdentityCard:
        return PassportElementTypeIdentityCard.construct(**q)


class PassportElementTypeInternalPassport(PassportElementType):
    """
    A Telegram Passport element containing the user's internal passport
    
    """

    ID: str = Field("passportElementTypeInternalPassport", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeInternalPassport:
        return PassportElementTypeInternalPassport.construct(**q)


class PassportElementTypePassport(PassportElementType):
    """
    A Telegram Passport element containing the user's passport
    
    """

    ID: str = Field("passportElementTypePassport", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypePassport:
        return PassportElementTypePassport.construct(**q)


class PassportElementTypePassportRegistration(PassportElementType):
    """
    A Telegram Passport element containing the registration page of the user's passport
    
    """

    ID: str = Field("passportElementTypePassportRegistration", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypePassportRegistration:
        return PassportElementTypePassportRegistration.construct(**q)


class PassportElementTypePersonalDetails(PassportElementType):
    """
    A Telegram Passport element containing the user's personal details
    
    """

    ID: str = Field("passportElementTypePersonalDetails", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypePersonalDetails:
        return PassportElementTypePersonalDetails.construct(**q)


class PassportElementTypePhoneNumber(PassportElementType):
    """
    A Telegram Passport element containing the user's phone number
    
    """

    ID: str = Field("passportElementTypePhoneNumber", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypePhoneNumber:
        return PassportElementTypePhoneNumber.construct(**q)


class PassportElementTypeRentalAgreement(PassportElementType):
    """
    A Telegram Passport element containing the user's rental agreement
    
    """

    ID: str = Field("passportElementTypeRentalAgreement", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeRentalAgreement:
        return PassportElementTypeRentalAgreement.construct(**q)


class PassportElementTypeTemporaryRegistration(PassportElementType):
    """
    A Telegram Passport element containing the user's temporary registration
    
    """

    ID: str = Field("passportElementTypeTemporaryRegistration", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeTemporaryRegistration:
        return PassportElementTypeTemporaryRegistration.construct(**q)


class PassportElementTypeUtilityBill(PassportElementType):
    """
    A Telegram Passport element containing the user's utility bill
    
    """

    ID: str = Field("passportElementTypeUtilityBill", alias="@type")

    @staticmethod
    def read(q: dict) -> PassportElementTypeUtilityBill:
        return PassportElementTypeUtilityBill.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CreateTemporaryPassword(BaseObject):
    """
    Creates a new temporary password for processing payments
    
    Params:
        password (:class:`str`)
            Persistent user password
        
        valid_for (:class:`int`)
            Time during which the temporary password will be valid, in seconds; should be between 60 and 86400
        
    """

    ID: str = Field("createTemporaryPassword", alias="@type")
    password: str
    valid_for: int

    @staticmethod
    def read(q: dict) -> CreateTemporaryPassword:
        return CreateTemporaryPassword.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class OpenChat(BaseObject):
    """
    Informs TDLib that the chat is opened by the user. Many useful activities depend on the chat being opened or closed (e.g., in supergroups and channels all updates are received only for opened chats)
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
    """

    ID: str = Field("openChat", alias="@type")
    chat_id: int

    @staticmethod
    def read(q: dict) -> OpenChat:
        return OpenChat.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CheckChatInviteLink(BaseObject):
    """
    Checks the validity of an invite link for a chat and returns information about the corresponding chat
    
    Params:
        invite_link (:class:`str`)
            Invite link to be checked
        
    """

    ID: str = Field("checkChatInviteLink", alias="@type")
    invite_link: str

    @staticmethod
    def read(q: dict) -> CheckChatInviteLink:
        return CheckChatInviteLink.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import AutoDownloadSettings
from ..types import NetworkType


class SetAutoDownloadSettings(BaseObject):
    """
    Sets auto-download settings
    
    Params:
        settings (:class:`AutoDownloadSettings`)
            New user auto-download settings
        
        type_ (:class:`NetworkType`)
            Type of the network for which the new settings are relevant
        
    """

    ID: str = Field("setAutoDownloadSettings", alias="@type")
    settings: AutoDownloadSettings
    type_: NetworkType = Field(..., alias='type')

    @staticmethod
    def read(q: dict) -> SetAutoDownloadSettings:
        return SetAutoDownloadSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SendCallSignalingData(BaseObject):
    """
    Sends call signaling data
    
    Params:
        call_id (:class:`int`)
            Call identifier
        
        data (:class:`str`)
            The data
        
    """

    ID: str = Field("sendCallSignalingData", alias="@type")
    call_id: int
    data: str

    @staticmethod
    def read(q: dict) -> SendCallSignalingData:
        return SendCallSignalingData.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetFileDownloadedPrefixSize(BaseObject):
    """
    Returns file downloaded prefix size from a given offset
    
    Params:
        file_id (:class:`int`)
            Identifier of the file
        
        offset (:class:`int`)
            Offset from which downloaded prefix size should be calculated
        
    """

    ID: str = Field("getFileDownloadedPrefixSize", alias="@type")
    file_id: int
    offset: int

    @staticmethod
    def read(q: dict) -> GetFileDownloadedPrefixSize:
        return GetFileDownloadedPrefixSize.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ViewMessages(BaseObject):
    """
    Informs TDLib that messages are being viewed by the user. Many useful activities depend on whether the messages are currently being viewed or not (e.g., marking messages as read, incrementing a view counter, updating a view counter, removing deleted messages in supergroups and channels)
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        message_thread_id (:class:`int`)
            If not 0, a message thread identifier in which the messages are being viewed
        
        message_ids (:obj:`list[int]`)
            The identifiers of the messages being viewed
        
        force_read (:class:`bool`)
            True, if messages in closed chats should be marked as read by the request
        
    """

    ID: str = Field("viewMessages", alias="@type")
    chat_id: int
    message_thread_id: int
    message_ids: list[int]
    force_read: bool

    @staticmethod
    def read(q: dict) -> ViewMessages:
        return ViewMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class LogOut(BaseObject):
    """
    Closes the TDLib instance after a proper logout. Requires an available network connection. All local data will be destroyed. After the logout completes, updateAuthorizationState with authorizationStateClosed will be sent
    
    """

    ID: str = Field("logOut", alias="@type")

    @staticmethod
    def read(q: dict) -> LogOut:
        return LogOut.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class CallId(BaseObject):
    """
    Contains the call identifier
    
    Params:
        id (:class:`int`)
            Call identifier
        
    """

    ID: str = Field("callId", alias="@type")
    id: int

    @staticmethod
    def read(q: dict) -> CallId:
        return CallId.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .input_file import InputFile
from ..base_object import BaseObject


class InputThumbnail(BaseObject):
    """
    A thumbnail to be sent along with a file; must be in JPEG or WEBP format for stickers, and less than 200 KB in size
    
    Params:
        thumbnail (:class:`InputFile`)
            Thumbnail file to send. Sending thumbnails by file_id is currently not supported
        
        width (:class:`int`)
            Thumbnail width, usually shouldn't exceed 320. Use 0 if unknown
        
        height (:class:`int`)
            Thumbnail height, usually shouldn't exceed 320. Use 0 if unknown
        
    """

    ID: str = Field("inputThumbnail", alias="@type")
    thumbnail: InputFile
    width: int
    height: int

    @staticmethod
    def read(q: dict) -> InputThumbnail:
        return InputThumbnail.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ResetPassword(BaseObject):
    """
    Removes 2-step verification password without previous password and access to recovery email address. The password can't be reset immediately and the request needs to be repeated after the specified time
    
    """

    ID: str = Field("resetPassword", alias="@type")

    @staticmethod
    def read(q: dict) -> ResetPassword:
        return ResetPassword.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class SecretChatState(BaseObject):
    """
    Describes the current secret chat state
    
    """

    ID: str = Field("secretChatState", alias="@type")


class SecretChatStateClosed(SecretChatState):
    """
    The secret chat is closed
    
    """

    ID: str = Field("secretChatStateClosed", alias="@type")

    @staticmethod
    def read(q: dict) -> SecretChatStateClosed:
        return SecretChatStateClosed.construct(**q)


class SecretChatStatePending(SecretChatState):
    """
    The secret chat is not yet created; waiting for the other user to get online
    
    """

    ID: str = Field("secretChatStatePending", alias="@type")

    @staticmethod
    def read(q: dict) -> SecretChatStatePending:
        return SecretChatStatePending.construct(**q)


class SecretChatStateReady(SecretChatState):
    """
    The secret chat is ready to use
    
    """

    ID: str = Field("secretChatStateReady", alias="@type")

    @staticmethod
    def read(q: dict) -> SecretChatStateReady:
        return SecretChatStateReady.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetInternalLinkType(BaseObject):
    """
    Returns information about the type of an internal link. Returns a 404 error if the link is not internal. Can be called before authorization
    
    Params:
        link (:class:`str`)
            The link
        
    """

    ID: str = Field("getInternalLinkType", alias="@type")
    link: str

    @staticmethod
    def read(q: dict) -> GetInternalLinkType:
        return GetInternalLinkType.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import InputFile


class ImportMessages(BaseObject):
    """
    Imports messages exported from another app
    
    Params:
        chat_id (:class:`int`)
            Identifier of a chat to which the messages will be imported. It must be an identifier of a private chat with a mutual contact or an identifier of a supergroup chat with can_change_info administrator right
        
        message_file (:class:`InputFile`)
            File with messages to import. Only inputFileLocal and inputFileGenerated are supported. The file must not be previously uploaded
        
        attached_files (:obj:`list[InputFile]`)
            Files used in the imported messages. Only inputFileLocal and inputFileGenerated are supported. The files must not be previously uploaded
        
    """

    ID: str = Field("importMessages", alias="@type")
    chat_id: int
    message_file: InputFile
    attached_files: list[InputFile]

    @staticmethod
    def read(q: dict) -> ImportMessages:
        return ImportMessages.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class ChatType(BaseObject):
    """
    Describes the type of a chat
    
    """

    ID: str = Field("chatType", alias="@type")


class ChatTypeBasicGroup(ChatType):
    """
    A basic group (i.e., a chat with 0-200 other users)
    
    Params:
        basic_group_id (:class:`int`)
            Basic group identifier
        
    """

    ID: str = Field("chatTypeBasicGroup", alias="@type")
    basic_group_id: int

    @staticmethod
    def read(q: dict) -> ChatTypeBasicGroup:
        return ChatTypeBasicGroup.construct(**q)


class ChatTypePrivate(ChatType):
    """
    An ordinary chat with a user
    
    Params:
        user_id (:class:`int`)
            User identifier
        
    """

    ID: str = Field("chatTypePrivate", alias="@type")
    user_id: int

    @staticmethod
    def read(q: dict) -> ChatTypePrivate:
        return ChatTypePrivate.construct(**q)


class ChatTypeSecret(ChatType):
    """
    A secret chat with a user
    
    Params:
        secret_chat_id (:class:`int`)
            Secret chat identifier
        
        user_id (:class:`int`)
            User identifier of the secret chat peer
        
    """

    ID: str = Field("chatTypeSecret", alias="@type")
    secret_chat_id: int
    user_id: int

    @staticmethod
    def read(q: dict) -> ChatTypeSecret:
        return ChatTypeSecret.construct(**q)


class ChatTypeSupergroup(ChatType):
    """
    A supergroup (i.e. a chat with up to GetOption("supergroup_max_size") other users), or channel (with unlimited members)
    
    Params:
        supergroup_id (:class:`int`)
            Supergroup or channel identifier
        
        is_channel (:class:`bool`)
            True, if the supergroup is a channel
        
    """

    ID: str = Field("chatTypeSupergroup", alias="@type")
    supergroup_id: int
    is_channel: bool

    @staticmethod
    def read(q: dict) -> ChatTypeSupergroup:
        return ChatTypeSupergroup.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject
from ..types import ChatNotificationSettings


class SetChatNotificationSettings(BaseObject):
    """
    Changes the notification settings of a chat. Notification settings of a chat with the current user (Saved Messages) can't be changed
    
    Params:
        chat_id (:class:`int`)
            Chat identifier
        
        notification_settings (:class:`ChatNotificationSettings`)
            New notification settings for the chat. If the chat is muted for more than 1 week, it is considered to be muted forever
        
    """

    ID: str = Field("setChatNotificationSettings", alias="@type")
    chat_id: int
    notification_settings: ChatNotificationSettings

    @staticmethod
    def read(q: dict) -> SetChatNotificationSettings:
        return SetChatNotificationSettings.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .chat_invite_link_count import ChatInviteLinkCount
from ..base_object import BaseObject


class ChatInviteLinkCounts(BaseObject):
    """
    Contains a list of chat invite link counts
    
    Params:
        invite_link_counts (:obj:`list[ChatInviteLinkCount]`)
            List of invite linkcounts
        
    """

    ID: str = Field("chatInviteLinkCounts", alias="@type")
    invite_link_counts: list[ChatInviteLinkCount]

    @staticmethod
    def read(q: dict) -> ChatInviteLinkCounts:
        return ChatInviteLinkCounts.construct(**q)



from __future__ import annotations

import asyncio
from collections.abc import Callable
from typing import (
    Any,
    Coroutine,
    Optional,
    TypeVar,
    Union,
)

from .api import BaseObject
from .filters import (
    BaseFilter,
    FilterCallable,
)

SomeUpdate = TypeVar('SomeUpdate', bound=BaseObject)
HandlerCallable = Callable[['aiotdlib.Client', SomeUpdate], Coroutine[Any, Any, None]]


class Handler(object):
    def __init__(self, function: HandlerCallable, *, filters: Union[BaseFilter, FilterCallable] = None):
        if filters is not None and not isinstance(filters, BaseFilter) and not asyncio.iscoroutinefunction(function):
            raise ValueError('filters should be an instance of BaseFilter!')

        self.function: HandlerCallable = function
        self.filters: Optional[FilterCallable] = filters

    async def __call__(self, client: 'Client', update: BaseObject):
        if callable(self.filters):
            filter_result = await self.filters(update)

            if not bool(filter_result):
                return

            if isinstance(filter_result, dict):
                update.EXTRA |= filter_result

        return await self.function(client, update)



import logging
from functools import wraps
from time import perf_counter

logger = logging.getLogger('measure_time')


def measure_time(func: callable):
    func_name = getattr(func, '__qualname__', '') or getattr(func, '__name__', '???')

    @wraps(func)
    def decorated(*args, **kwargs):
        start_time = perf_counter()

        try:
            return func(*args, **kwargs)
        finally:
            end_time = perf_counter() - start_time
            logger.info(f"{func_name} call finished in {end_time} seconds")

    return decorated



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

import typing

from pydantic import Field

from .profile_photo import ProfilePhoto
from .user_status import UserStatus
from .user_type import UserType
from ..base_object import BaseObject


class User(BaseObject):
    """
    Represents a user
    
    Params:
        id (:class:`int`)
            User identifier
        
        first_name (:class:`str`)
            First name of the user
        
        last_name (:class:`str`)
            Last name of the user
        
        username (:class:`str`)
            Username of the user
        
        phone_number (:class:`str`)
            Phone number of the user
        
        status (:class:`UserStatus`)
            Current online status of the user
        
        profile_photo (:class:`ProfilePhoto`)
            Profile photo of the user; may be null
        
        is_contact (:class:`bool`)
            The user is a contact of the current user
        
        is_mutual_contact (:class:`bool`)
            The user is a contact of the current user and the current user is a contact of the user
        
        is_verified (:class:`bool`)
            True, if the user is verified
        
        is_support (:class:`bool`)
            True, if the user is Telegram support account
        
        restriction_reason (:class:`str`)
            If non-empty, it contains a human-readable description of the reason why access to this user must be restricted
        
        is_scam (:class:`bool`)
            True, if many users reported this user as a scam
        
        is_fake (:class:`bool`)
            True, if many users reported this user as a fake account
        
        have_access (:class:`bool`)
            If false, the user is inaccessible, and the only information known about the user is inside this class. It can't be passed to any method except GetUser
        
        type_ (:class:`UserType`)
            Type of the user
        
        language_code (:class:`str`)
            IETF language tag of the user's language; only available to bots
        
    """

    ID: str = Field("user", alias="@type")
    id: int
    first_name: str
    last_name: str
    username: str
    phone_number: str
    status: UserStatus
    profile_photo: typing.Optional[ProfilePhoto] = None
    is_contact: bool
    is_mutual_contact: bool
    is_verified: bool
    is_support: bool
    restriction_reason: str
    is_scam: bool
    is_fake: bool
    have_access: bool
    type_: UserType = Field(..., alias='type')
    language_code: str

    @staticmethod
    def read(q: dict) -> User:
        return User.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class AcceptTermsOfService(BaseObject):
    """
    Accepts Telegram terms of services
    
    Params:
        terms_of_service_id (:class:`str`)
            Terms of service identifier
        
    """

    ID: str = Field("acceptTermsOfService", alias="@type")
    terms_of_service_id: str

    @staticmethod
    def read(q: dict) -> AcceptTermsOfService:
        return AcceptTermsOfService.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class DeviceToken(BaseObject):
    """
    Represents a data needed to subscribe for push notifications through registerDevice method. To use specific push notification service, the correct application platform must be specified and a valid server authentication data must be uploaded at https://my.telegram.org
    
    """

    ID: str = Field("deviceToken", alias="@type")


class DeviceTokenApplePush(DeviceToken):
    """
    A token for Apple Push Notification service
    
    Params:
        device_token (:class:`str`)
            Device token; may be empty to de-register a device
        
        is_app_sandbox (:class:`bool`)
            True, if App Sandbox is enabled
        
    """

    ID: str = Field("deviceTokenApplePush", alias="@type")
    device_token: str
    is_app_sandbox: bool

    @staticmethod
    def read(q: dict) -> DeviceTokenApplePush:
        return DeviceTokenApplePush.construct(**q)


class DeviceTokenApplePushVoIP(DeviceToken):
    """
    A token for Apple Push Notification service VoIP notifications
    
    Params:
        device_token (:class:`str`)
            Device token; may be empty to de-register a device
        
        is_app_sandbox (:class:`bool`)
            True, if App Sandbox is enabled
        
        encrypt (:class:`bool`)
            True, if push notifications should be additionally encrypted
        
    """

    ID: str = Field("deviceTokenApplePushVoIP", alias="@type")
    device_token: str
    is_app_sandbox: bool
    encrypt: bool

    @staticmethod
    def read(q: dict) -> DeviceTokenApplePushVoIP:
        return DeviceTokenApplePushVoIP.construct(**q)


class DeviceTokenBlackBerryPush(DeviceToken):
    """
    A token for BlackBerry Push Service
    
    Params:
        token (:class:`str`)
            Token; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenBlackBerryPush", alias="@type")
    token: str

    @staticmethod
    def read(q: dict) -> DeviceTokenBlackBerryPush:
        return DeviceTokenBlackBerryPush.construct(**q)


class DeviceTokenFirebaseCloudMessaging(DeviceToken):
    """
    A token for Firebase Cloud Messaging
    
    Params:
        token (:class:`str`)
            Device registration token; may be empty to de-register a device
        
        encrypt (:class:`bool`)
            True, if push notifications should be additionally encrypted
        
    """

    ID: str = Field("deviceTokenFirebaseCloudMessaging", alias="@type")
    token: str
    encrypt: bool

    @staticmethod
    def read(q: dict) -> DeviceTokenFirebaseCloudMessaging:
        return DeviceTokenFirebaseCloudMessaging.construct(**q)


class DeviceTokenMicrosoftPush(DeviceToken):
    """
    A token for Microsoft Push Notification Service
    
    Params:
        channel_uri (:class:`str`)
            Push notification channel URI; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenMicrosoftPush", alias="@type")
    channel_uri: str

    @staticmethod
    def read(q: dict) -> DeviceTokenMicrosoftPush:
        return DeviceTokenMicrosoftPush.construct(**q)


class DeviceTokenMicrosoftPushVoIP(DeviceToken):
    """
    A token for Microsoft Push Notification Service VoIP channel
    
    Params:
        channel_uri (:class:`str`)
            Push notification channel URI; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenMicrosoftPushVoIP", alias="@type")
    channel_uri: str

    @staticmethod
    def read(q: dict) -> DeviceTokenMicrosoftPushVoIP:
        return DeviceTokenMicrosoftPushVoIP.construct(**q)


class DeviceTokenSimplePush(DeviceToken):
    """
    A token for Simple Push API for Firefox OS
    
    Params:
        endpoint (:class:`str`)
            Absolute URL exposed by the push service where the application server can send push messages; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenSimplePush", alias="@type")
    endpoint: str

    @staticmethod
    def read(q: dict) -> DeviceTokenSimplePush:
        return DeviceTokenSimplePush.construct(**q)


class DeviceTokenTizenPush(DeviceToken):
    """
    A token for Tizen Push Service
    
    Params:
        reg_id (:class:`str`)
            Push service registration identifier; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenTizenPush", alias="@type")
    reg_id: str

    @staticmethod
    def read(q: dict) -> DeviceTokenTizenPush:
        return DeviceTokenTizenPush.construct(**q)


class DeviceTokenUbuntuPush(DeviceToken):
    """
    A token for Ubuntu Push Client service
    
    Params:
        token (:class:`str`)
            Token; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenUbuntuPush", alias="@type")
    token: str

    @staticmethod
    def read(q: dict) -> DeviceTokenUbuntuPush:
        return DeviceTokenUbuntuPush.construct(**q)


class DeviceTokenWebPush(DeviceToken):
    """
    A token for web Push API
    
    Params:
        endpoint (:class:`str`)
            Absolute URL exposed by the push service where the application server can send push messages; may be empty to de-register a device
        
        p256dh_base64url (:class:`str`)
            Base64url-encoded P-256 elliptic curve Diffie-Hellman public key
        
        auth_base64url (:class:`str`)
            Base64url-encoded authentication secret
        
    """

    ID: str = Field("deviceTokenWebPush", alias="@type")
    endpoint: str
    p256dh_base64url: str
    auth_base64url: str

    @staticmethod
    def read(q: dict) -> DeviceTokenWebPush:
        return DeviceTokenWebPush.construct(**q)


class DeviceTokenWindowsPush(DeviceToken):
    """
    A token for Windows Push Notification Services
    
    Params:
        access_token (:class:`str`)
            The access token that will be used to send notifications; may be empty to de-register a device
        
    """

    ID: str = Field("deviceTokenWindowsPush", alias="@type")
    access_token: str

    @staticmethod
    def read(q: dict) -> DeviceTokenWindowsPush:
        return DeviceTokenWindowsPush.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class GetLogTags(BaseObject):
    """
    Returns list of available TDLib internal log tags, for example, ["actor", "binlog", "connections", "notifications", "proxy"]. Can be called synchronously
    
    """

    ID: str = Field("getLogTags", alias="@type")

    @staticmethod
    def read(q: dict) -> GetLogTags:
        return GetLogTags.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .labeled_price_part import LabeledPricePart
from ..base_object import BaseObject


class ShippingOption(BaseObject):
    """
    One shipping option
    
    Params:
        id (:class:`str`)
            Shipping option identifier
        
        title (:class:`str`)
            Option title
        
        price_parts (:obj:`list[LabeledPricePart]`)
            A list of objects used to calculate the total shipping costs
        
    """

    ID: str = Field("shippingOption", alias="@type")
    id: str
    title: str
    price_parts: list[LabeledPricePart]

    @staticmethod
    def read(q: dict) -> ShippingOption:
        return ShippingOption.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .message_sender import MessageSender
from ..base_object import BaseObject


class GroupCallRecentSpeaker(BaseObject):
    """
    Describes a recently speaking participant in a group call
    
    Params:
        participant_id (:class:`MessageSender`)
            Group call participant identifier
        
        is_speaking (:class:`bool`)
            True, is the user has spoken recently
        
    """

    ID: str = Field("groupCallRecentSpeaker", alias="@type")
    participant_id: MessageSender
    is_speaking: bool

    @staticmethod
    def read(q: dict) -> GroupCallRecentSpeaker:
        return GroupCallRecentSpeaker.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from .location import Location
from ..base_object import BaseObject


class ChatLocation(BaseObject):
    """
    Represents a location to which a chat is connected
    
    Params:
        location (:class:`Location`)
            The location
        
        address (:class:`str`)
            Location address; 1-64 characters, as defined by the chat owner
        
    """

    ID: str = Field("chatLocation", alias="@type")
    location: Location
    address: str = Field(..., min_length=1, max_length=64)

    @staticmethod
    def read(q: dict) -> ChatLocation:
        return ChatLocation.construct(**q)



# =============================================================================== #
#                                                                                 #
#    This file has been generated automatically!! Do not change this manually!    #
#                                                                                 #
# =============================================================================== #
from __future__ import annotations

from pydantic import Field

from ..base_object import BaseObject


class StatisticalValue(BaseObject):
    """
    A value with information about its recent changes
    
    Params:
        value (:class:`float`)
            The current value
        
        previous_value (:class:`float`)
            The value for the previous day
        
        growth_rate_percentage (:class:`float`)
            The growth rate of the value, as a percentage
        
    """

    ID: str = Field("statisticalValue", alias="@type")
    value: float
    previous_value: float
    growth_rate_percentage: float

    @staticmethod
    def read(q: dict) -> StatisticalValue:
        return StatisticalValue.construct(**q)
